@@ -22,22 +22,17 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 
-
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-    unicode_literals,
-)
+from __future__ import absolute_import, division, print_function, unicode_literals
 
 from future import standard_library
+
 standard_library.install_aliases()
 
-from builtins import *
 import urllib.parse
+from builtins import *
 
-from past.builtins import basestring
 import requests
+from past.builtins import basestring
 
 from ..response_codes import EXPECTED_RESPONSE_CODE
 from ..utils import (
