@@ -22,13 +22,7 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 
-
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-    unicode_literals,
-)
+from __future__ import absolute_import, division, print_function, unicode_literals
 
 from builtins import *
 
@@ -36,15 +30,15 @@ from past.builtins import basestring
 
 from ...restsession import RestSession
 from ...utils import (
+    apply_path_params,
     check_type,
     dict_from_items_with_values,
-    apply_path_params,
     dict_of_str,
 )
 
 
 class Networks(object):
-    """Cisco DNA Center Networks API (version: 1.3.0).
+    """Cisco DNA Center Networks API (version: 1.2.10).
 
     Wraps the DNA Center Networks
     API and exposes the API as native Python
@@ -120,7 +114,7 @@ class Networks(object):
         else:
             json_data = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_6284db4649aa8d31_v1_3_0', json_data)
+        return self._object_factory('bpm_6284db4649aa8d31_v1_2_10', json_data)
 
     def get_site_topology(self,
                           headers=None,
@@ -170,7 +164,7 @@ class Networks(object):
         else:
             json_data = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_9ba14a9e441b8a60_v1_3_0', json_data)
+        return self._object_factory('bpm_9ba14a9e441b8a60_v1_2_10', json_data)
 
     def get_physical_topology(self,
                               node_type=None,
@@ -226,62 +220,7 @@ class Networks(object):
         else:
             json_data = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_b2b8cb91459aa58f_v1_3_0', json_data)
-
-    def get_topology_details(self,
-                             vlan_id,
-                             headers=None,
-                             **request_parameters):
-        """Returns Layer 2 network topology by specified VLAN ID.
-
-        Args:
-            vlan_id(basestring): Vlan Name for e.g Vlan1, Vlan23 etc.
-            headers(dict): Dictionary of HTTP Headers to send with the Request
-                .
-            **request_parameters: Additional request parameters (provides
-                support for parameters that may be added in the future).
-
-        Returns:
-            MyDict: JSON response. Access the object's properties by using
-            the dot notation or the bracket notation.
-
-        Raises:
-            TypeError: If the parameter types are incorrect.
-            MalformedRequest: If the request body created is invalid.
-            ApiError: If the DNA Center cloud returns an error.
-        """
-        check_type(headers, dict)
-        check_type(vlan_id, basestring,
-                   may_be_none=False)
-        if headers is not None:
-            if 'X-Auth-Token' in headers:
-                check_type(headers.get('X-Auth-Token'),
-                           basestring, may_be_none=False)
-
-        _params = {
-        }
-        _params.update(request_parameters)
-        _params = dict_from_items_with_values(_params)
-
-        path_params = {
-            'vlanID': vlan_id,
-        }
-
-        with_custom_headers = False
-        _headers = self._session.headers or {}
-        if headers:
-            _headers.update(dict_of_str(headers))
-            with_custom_headers = True
-
-        e_url = ('/dna/intent/api/v1/topology/l2/${vlanID}')
-        endpoint_full_url = apply_path_params(e_url, path_params)
-        if with_custom_headers:
-            json_data = self._session.get(endpoint_full_url, params=_params,
-                                          headers=_headers)
-        else:
-            json_data = self._session.get(endpoint_full_url, params=_params)
-
-        return self._object_factory('bpm_b9b48ac8463a8aba_v1_3_0', json_data)
+        return self._object_factory('bpm_b2b8cb91459aa58f_v1_2_10', json_data)
 
     def get_l3_topology_details(self,
                                 topology_type,
@@ -336,7 +275,62 @@ class Networks(object):
         else:
             json_data = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_c2b5fb764d888375_v1_3_0', json_data)
+        return self._object_factory('bpm_c2b5fb764d888375_v1_2_10', json_data)
+
+    def get_topology_details(self,
+                             vlan_id,
+                             headers=None,
+                             **request_parameters):
+        """Returns Layer 2 network topology by specified VLAN ID.
+
+        Args:
+            vlan_id(basestring): Vlan Name for e.g Vlan1, Vlan23 etc.
+            headers(dict): Dictionary of HTTP Headers to send with the Request
+                .
+            **request_parameters: Additional request parameters (provides
+                support for parameters that may be added in the future).
+
+        Returns:
+            MyDict: JSON response. Access the object's properties by using
+            the dot notation or the bracket notation.
+
+        Raises:
+            TypeError: If the parameter types are incorrect.
+            MalformedRequest: If the request body created is invalid.
+            ApiError: If the DNA Center cloud returns an error.
+        """
+        check_type(headers, dict)
+        check_type(vlan_id, basestring,
+                   may_be_none=False)
+        if headers is not None:
+            if 'X-Auth-Token' in headers:
+                check_type(headers.get('X-Auth-Token'),
+                           basestring, may_be_none=False)
+
+        _params = {
+        }
+        _params.update(request_parameters)
+        _params = dict_from_items_with_values(_params)
+
+        path_params = {
+            'vlanID': vlan_id,
+        }
+
+        with_custom_headers = False
+        _headers = self._session.headers or {}
+        if headers:
+            _headers.update(dict_of_str(headers))
+            with_custom_headers = True
+
+        e_url = ('/dna/intent/api/v1/topology/l2/${vlanID}')
+        endpoint_full_url = apply_path_params(e_url, path_params)
+        if with_custom_headers:
+            json_data = self._session.get(endpoint_full_url, params=_params,
+                                          headers=_headers)
+        else:
+            json_data = self._session.get(endpoint_full_url, params=_params)
+
+        return self._object_factory('bpm_b9b48ac8463a8aba_v1_2_10', json_data)
 
     def get_overall_network_health(self,
                                    timestamp=None,
@@ -397,4 +391,4 @@ class Networks(object):
         else:
             json_data = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_ca91da84401abba1_v1_3_0', json_data)
+        return self._object_factory('bpm_ca91da84401abba1_v1_2_10', json_data)
