@@ -22,13 +22,7 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 
-
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-    unicode_literals,
-)
+from __future__ import absolute_import, division, print_function, unicode_literals
 
 from builtins import *
 
@@ -36,15 +30,15 @@ from past.builtins import basestring
 
 from ...restsession import RestSession
 from ...utils import (
+    apply_path_params,
     check_type,
     dict_from_items_with_values,
-    apply_path_params,
     dict_of_str,
 )
 
 
 class SiteProfile(object):
-    """Cisco DNA Center Site Profile API (version: 1.3.0).
+    """Cisco DNA Center Site Profile API (version: 1.2.10).
 
     Wraps the DNA Center Site Profile
     API and exposes the API as native Python
@@ -76,8 +70,8 @@ class SiteProfile(object):
                                  device_ip,
                                  headers=None,
                                  **request_parameters):
-        """Returns provisioning device information for the specified IP
-        address.
+        """**Beta** - Returns provisioning device information for the
+        specified IP address.
 
         Args:
             device_ip(basestring): Device to which the provisioning detail has to be retrieved.
@@ -127,9 +121,10 @@ class SiteProfile(object):
         else:
             json_data = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_7fbe4b804879baa4_v1_3_0', json_data)
+        return self._object_factory('bpm_7fbe4b804879baa4_v1_2_10', json_data)
 
     def provision_nfv(self,
+                      callbackUrl=None,
                       provisioning=None,
                       siteProfile=None,
                       headers=None,
@@ -140,6 +135,7 @@ class SiteProfile(object):
         site/area/building/floor .
 
         Args:
+            callbackUrl(string): Callback Url, property of the request body.
             provisioning(list): Provisioning, property of the request body (list of objects).
             siteProfile(list): Site Profile, property of the request body (list of objects).
             headers(dict): Dictionary of HTTP Headers to send with the Request
@@ -169,8 +165,8 @@ class SiteProfile(object):
             if '__persistbapioutput' in headers:
                 check_type(headers.get('__persistbapioutput'),
                            bool, may_be_none=False)
-            if '__runsynctimeout' in headers:
-                check_type(headers.get('__runsynctimeout'),
+            if '__timeout' in headers:
+                check_type(headers.get('__timeout'),
                            int)
             if 'X-Auth-Token' in headers:
                 check_type(headers.get('X-Auth-Token'),
@@ -189,11 +185,13 @@ class SiteProfile(object):
                 siteProfile,
             'provisioning':
                 provisioning,
+            'callbackUrl':
+                callbackUrl,
         }
         _payload.update(payload or {})
         _payload = dict_from_items_with_values(_payload)
         if active_validation:
-            self._request_validator('jsd_828828f44f28bd0d_v1_3_0')\
+            self._request_validator('jsd_828828f44f28bd0d_v1_2_10')\
                 .validate(_payload)
 
         with_custom_headers = False
@@ -212,85 +210,4 @@ class SiteProfile(object):
             json_data = self._session.post(endpoint_full_url, params=_params,
                                            json=_payload)
 
-        return self._object_factory('bpm_828828f44f28bd0d_v1_3_0', json_data)
-
-    def nfv_provisioning_detail(self,
-                                device_ip=None,
-                                headers=None,
-                                payload=None,
-                                active_validation=True,
-                                **request_parameters):
-        """Checks the provisioning detail of an ENCS device including log
-        information.
-
-        Args:
-            device_ip(string): Device Ip, property of the request body.
-            headers(dict): Dictionary of HTTP Headers to send with the Request
-                .
-            payload(dict): A JSON serializable Python object to send in the
-                body of the Request.
-            active_validation(bool): Enable/Disable payload validation.
-                Defaults to True.
-            **request_parameters: Additional request parameters (provides
-                support for parameters that may be added in the future).
-
-        Returns:
-            MyDict: JSON response. Access the object's properties by using
-            the dot notation or the bracket notation.
-
-        Raises:
-            TypeError: If the parameter types are incorrect.
-            MalformedRequest: If the request body created is invalid.
-            ApiError: If the DNA Center cloud returns an error.
-        """
-        check_type(headers, dict)
-        check_type(payload, dict)
-        if headers is not None:
-            if '__runsync' in headers:
-                check_type(headers.get('__runsync'),
-                           bool, may_be_none=False)
-            if '__runsynctimeout' in headers:
-                check_type(headers.get('__runsynctimeout'),
-                           int)
-            if '__persistbapioutput' in headers:
-                check_type(headers.get('__persistbapioutput'),
-                           bool, may_be_none=False)
-            if 'X-Auth-Token' in headers:
-                check_type(headers.get('X-Auth-Token'),
-                           basestring, may_be_none=False)
-
-        _params = {
-        }
-        _params.update(request_parameters)
-        _params = dict_from_items_with_values(_params)
-
-        path_params = {
-        }
-
-        _payload = {
-            'device_ip':
-                device_ip,
-        }
-        _payload.update(payload or {})
-        _payload = dict_from_items_with_values(_payload)
-        if active_validation:
-            self._request_validator('jsd_2f97e8fa45f8b2a3_v1_3_0')\
-                .validate(_payload)
-
-        with_custom_headers = False
-        _headers = self._session.headers or {}
-        if headers:
-            _headers.update(dict_of_str(headers))
-            with_custom_headers = True
-
-        e_url = ('/dna/intent/api/v1/nfv-provision-detail')
-        endpoint_full_url = apply_path_params(e_url, path_params)
-        if with_custom_headers:
-            json_data = self._session.post(endpoint_full_url, params=_params,
-                                           json=_payload,
-                                           headers=_headers)
-        else:
-            json_data = self._session.post(endpoint_full_url, params=_params,
-                                           json=_payload)
-
-        return self._object_factory('bpm_2f97e8fa45f8b2a3_v1_3_0', json_data)
+        return self._object_factory('bpm_828828f44f28bd0d_v1_2_10', json_data)
