@@ -22,13 +22,7 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 
-
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-    unicode_literals,
-)
+from __future__ import absolute_import, division, print_function, unicode_literals
 
 from builtins import *
 
@@ -36,15 +30,15 @@ from past.builtins import basestring
 
 from ...restsession import RestSession
 from ...utils import (
+    apply_path_params,
     check_type,
     dict_from_items_with_values,
-    apply_path_params,
     dict_of_str,
 )
 
 
 class Swim(object):
-    """Cisco DNA Center SWIM API (version: 1.3.0).
+    """Cisco DNA Center SWIM API (version: 1.2.10).
 
     Wraps the DNA Center SWIM
     API and exposes the API as native Python
@@ -211,7 +205,7 @@ class Swim(object):
         else:
             json_data = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_0c8f7a0b49b9aedd_v1_3_0', json_data)
+        return self._object_factory('bpm_0c8f7a0b49b9aedd_v1_2_10', json_data)
 
     def trigger_software_image_distribution(self,
                                             headers=None,
@@ -261,7 +255,7 @@ class Swim(object):
 
         _payload = payload or []
         if active_validation:
-            self._request_validator('jsd_8cb6783b4faba1f4_v1_3_0')\
+            self._request_validator('jsd_8cb6783b4faba1f4_v1_2_10')\
                 .validate(_payload)
 
         with_custom_headers = False
@@ -280,7 +274,7 @@ class Swim(object):
             json_data = self._session.post(endpoint_full_url, params=_params,
                                            json=_payload)
 
-        return self._object_factory('bpm_8cb6783b4faba1f4_v1_3_0', json_data)
+        return self._object_factory('bpm_8cb6783b4faba1f4_v1_2_10', json_data)
 
     def import_local_software_image(self,
                                     multipart_fields,
@@ -296,10 +290,7 @@ class Swim(object):
         are bin, img, tar, smu, pie, aes, iso, ova, tar_gz and
         qcow2.
 
-        The following code gives an **example** of the multipart_fields,
-        using `file` and `images` as form data field.
-
-        Use the appropiate form data field for the function.
+        The following code gives an example of the multipart_fields.
 
         .. code-block:: python
 
@@ -399,86 +390,7 @@ class Swim(object):
         else:
             json_data = self._session.post(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_4dbe3bc743a891bc_v1_3_0', json_data)
-
-    def trigger_software_image_activation(self,
-                                          schedule_validate=None,
-                                          headers=None,
-                                          payload=None,
-                                          active_validation=True,
-                                          **request_parameters):
-        """Activates a software image on a given device. Software image
-        must be present in the device flash.
-
-        Args:
-            schedule_validate(bool): scheduleValidate, validates data before schedule (Optional).
-            headers(dict): Dictionary of HTTP Headers to send with the Request
-                .
-            payload(list): A JSON serializable Python object to send in the
-                body of the Request.
-            active_validation(bool): Enable/Disable payload validation.
-                Defaults to True.
-            **request_parameters: Additional request parameters (provides
-                support for parameters that may be added in the future).
-
-        Returns:
-            MyDict: JSON response. Access the object's properties by using
-            the dot notation or the bracket notation.
-
-        Raises:
-            TypeError: If the parameter types are incorrect.
-            MalformedRequest: If the request body created is invalid.
-            ApiError: If the DNA Center cloud returns an error.
-        """
-        check_type(headers, dict)
-        check_type(payload, list)
-        check_type(schedule_validate, bool)
-        if headers is not None:
-            if 'Content-Type' in headers:
-                check_type(headers.get('Content-Type'),
-                           basestring, may_be_none=False)
-            if 'Client-Type' in headers:
-                check_type(headers.get('Client-Type'),
-                           basestring)
-            if 'Client-Url' in headers:
-                check_type(headers.get('Client-Url'),
-                           basestring)
-            if 'X-Auth-Token' in headers:
-                check_type(headers.get('X-Auth-Token'),
-                           basestring, may_be_none=False)
-
-        _params = {
-            'scheduleValidate':
-                schedule_validate,
-        }
-        _params.update(request_parameters)
-        _params = dict_from_items_with_values(_params)
-
-        path_params = {
-        }
-
-        _payload = payload or []
-        if active_validation:
-            self._request_validator('jsd_fb9beb664f2aba4c_v1_3_0')\
-                .validate(_payload)
-
-        with_custom_headers = False
-        _headers = self._session.headers or {}
-        if headers:
-            _headers.update(dict_of_str(headers))
-            with_custom_headers = True
-
-        e_url = ('/dna/intent/api/v1/image/activation/device')
-        endpoint_full_url = apply_path_params(e_url, path_params)
-        if with_custom_headers:
-            json_data = self._session.post(endpoint_full_url, params=_params,
-                                           json=_payload,
-                                           headers=_headers)
-        else:
-            json_data = self._session.post(endpoint_full_url, params=_params,
-                                           json=_payload)
-
-        return self._object_factory('bpm_fb9beb664f2aba4c_v1_3_0', json_data)
+        return self._object_factory('bpm_4dbe3bc743a891bc_v1_2_10', json_data)
 
     def import_software_image_via_url(self,
                                       schedule_at=None,
@@ -545,7 +457,7 @@ class Swim(object):
 
         _payload = payload or []
         if active_validation:
-            self._request_validator('jsd_bc8aab4746ca883d_v1_3_0')\
+            self._request_validator('jsd_bc8aab4746ca883d_v1_2_10')\
                 .validate(_payload)
 
         with_custom_headers = False
@@ -564,4 +476,83 @@ class Swim(object):
             json_data = self._session.post(endpoint_full_url, params=_params,
                                            json=_payload)
 
-        return self._object_factory('bpm_bc8aab4746ca883d_v1_3_0', json_data)
+        return self._object_factory('bpm_bc8aab4746ca883d_v1_2_10', json_data)
+
+    def trigger_software_image_activation(self,
+                                          schedule_validate=None,
+                                          headers=None,
+                                          payload=None,
+                                          active_validation=True,
+                                          **request_parameters):
+        """Activates a software image on a given device. Software image
+        must be present in the device flash.
+
+        Args:
+            schedule_validate(bool): scheduleValidate, validates data before schedule (Optional).
+            headers(dict): Dictionary of HTTP Headers to send with the Request
+                .
+            payload(list): A JSON serializable Python object to send in the
+                body of the Request.
+            active_validation(bool): Enable/Disable payload validation.
+                Defaults to True.
+            **request_parameters: Additional request parameters (provides
+                support for parameters that may be added in the future).
+
+        Returns:
+            MyDict: JSON response. Access the object's properties by using
+            the dot notation or the bracket notation.
+
+        Raises:
+            TypeError: If the parameter types are incorrect.
+            MalformedRequest: If the request body created is invalid.
+            ApiError: If the DNA Center cloud returns an error.
+        """
+        check_type(headers, dict)
+        check_type(payload, list)
+        check_type(schedule_validate, bool)
+        if headers is not None:
+            if 'Content-Type' in headers:
+                check_type(headers.get('Content-Type'),
+                           basestring, may_be_none=False)
+            if 'Client-Type' in headers:
+                check_type(headers.get('Client-Type'),
+                           basestring)
+            if 'Client-Url' in headers:
+                check_type(headers.get('Client-Url'),
+                           basestring)
+            if 'X-Auth-Token' in headers:
+                check_type(headers.get('X-Auth-Token'),
+                           basestring, may_be_none=False)
+
+        _params = {
+            'scheduleValidate':
+                schedule_validate,
+        }
+        _params.update(request_parameters)
+        _params = dict_from_items_with_values(_params)
+
+        path_params = {
+        }
+
+        _payload = payload or []
+        if active_validation:
+            self._request_validator('jsd_fb9beb664f2aba4c_v1_2_10')\
+                .validate(_payload)
+
+        with_custom_headers = False
+        _headers = self._session.headers or {}
+        if headers:
+            _headers.update(dict_of_str(headers))
+            with_custom_headers = True
+
+        e_url = ('/dna/intent/api/v1/image/activation/device')
+        endpoint_full_url = apply_path_params(e_url, path_params)
+        if with_custom_headers:
+            json_data = self._session.post(endpoint_full_url, params=_params,
+                                           json=_payload,
+                                           headers=_headers)
+        else:
+            json_data = self._session.post(endpoint_full_url, params=_params,
+                                           json=_payload)
+
+        return self._object_factory('bpm_fb9beb664f2aba4c_v1_2_10', json_data)
