@@ -22,13 +22,7 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 
-
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-    unicode_literals,
-)
+from __future__ import absolute_import, division, print_function, unicode_literals
 
 from builtins import *
 
@@ -36,15 +30,15 @@ from past.builtins import basestring
 
 from ...restsession import RestSession
 from ...utils import (
+    apply_path_params,
     check_type,
     dict_from_items_with_values,
-    apply_path_params,
     dict_of_str,
 )
 
 
 class Users(object):
-    """Cisco DNA Center Users API (version: 2.1.2).
+    """Cisco DNA Center Users API (version: 1.3.1).
 
     Wraps the DNA Center Users
     API and exposes the API as native Python
@@ -76,7 +70,7 @@ class Users(object):
                                     headers=None,
                                     **request_parameters):
         """Enriches a given network End User context (a network user-id or
-        end user's device Mac Address) with details about the
+        end user’s device Mac Address) with details about the
         user and devices that the user is connected to.
 
         Args:
@@ -129,4 +123,4 @@ class Users(object):
         else:
             json_data = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_d7a6392845e8969d_v2_1_2', json_data)
+        return self._object_factory('bpm_d7a6392845e8969d_v1_3_1', json_data)
