@@ -22,13 +22,7 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 
-
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-    unicode_literals,
-)
+from __future__ import absolute_import, division, print_function, unicode_literals
 
 from builtins import *
 
@@ -36,15 +30,15 @@ from past.builtins import basestring
 
 from ...restsession import RestSession
 from ...utils import (
+    apply_path_params,
     check_type,
     dict_from_items_with_values,
-    apply_path_params,
     dict_of_str,
 )
 
 
 class ApplicationPolicy(object):
-    """Cisco DNA Center Application Policy API (version: 2.2.2.3).
+    """Cisco DNA Center Application Policy API (version: 1.3.3).
 
     Wraps the DNA Center Application Policy
     API and exposes the API as native Python
@@ -72,13 +66,313 @@ class ApplicationPolicy(object):
         self._object_factory = object_factory
         self._request_validator = request_validator
 
+    def get_applications_count(self,
+                               headers=None,
+                               **request_parameters):
+        """Get the number of all existing applications.
+
+        Args:
+            headers(dict): Dictionary of HTTP Headers to send with the Request
+                .
+            **request_parameters: Additional request parameters (provides
+                support for parameters that may be added in the future).
+
+        Returns:
+            MyDict: JSON response. Access the object's properties by using
+            the dot notation or the bracket notation.
+
+        Raises:
+            TypeError: If the parameter types are incorrect.
+            MalformedRequest: If the request body created is invalid.
+            ApiError: If the DNA Center cloud returns an error.
+        """
+        check_type(headers, dict)
+        if headers is not None:
+            if 'X-Auth-Token' in headers:
+                check_type(headers.get('X-Auth-Token'),
+                           basestring, may_be_none=False)
+
+        _params = {
+        }
+        _params.update(request_parameters)
+        _params = dict_from_items_with_values(_params)
+
+        path_params = {
+        }
+
+        with_custom_headers = False
+        _headers = self._session.headers or {}
+        if headers:
+            _headers.update(dict_of_str(headers))
+            with_custom_headers = True
+
+        e_url = ('/dna/intent/api/v1/applications-count')
+        endpoint_full_url = apply_path_params(e_url, path_params)
+        if with_custom_headers:
+            json_data = self._session.get(endpoint_full_url, params=_params,
+                                          headers=_headers)
+        else:
+            json_data = self._session.get(endpoint_full_url, params=_params)
+
+        return self._object_factory('bpm_039de8b147a98690_v1_3_3', json_data)
+
+    def edit_application(self,
+                         headers=None,
+                         payload=None,
+                         active_validation=True,
+                         **request_parameters):
+        """Edit the attributes of an existing application.
+
+        Args:
+            headers(dict): Dictionary of HTTP Headers to send with the Request
+                .
+            payload(list): A JSON serializable Python object to send in the
+                body of the Request.
+            active_validation(bool): Enable/Disable payload validation.
+                Defaults to True.
+            **request_parameters: Additional request parameters (provides
+                support for parameters that may be added in the future).
+
+        Returns:
+            MyDict: JSON response. Access the object's properties by using
+            the dot notation or the bracket notation.
+
+        Raises:
+            TypeError: If the parameter types are incorrect.
+            MalformedRequest: If the request body created is invalid.
+            ApiError: If the DNA Center cloud returns an error.
+        """
+        check_type(headers, dict)
+        check_type(payload, list)
+        if headers is not None:
+            if 'X-Auth-Token' in headers:
+                check_type(headers.get('X-Auth-Token'),
+                           basestring, may_be_none=False)
+
+        _params = {
+        }
+        _params.update(request_parameters)
+        _params = dict_from_items_with_values(_params)
+
+        path_params = {
+        }
+
+        _payload = payload or []
+        if active_validation:
+            self._request_validator('jsd_398668874439a41d_v1_3_3')\
+                .validate(_payload)
+
+        with_custom_headers = False
+        _headers = self._session.headers or {}
+        if headers:
+            _headers.update(dict_of_str(headers))
+            with_custom_headers = True
+
+        e_url = ('/dna/intent/api/v1/applications')
+        endpoint_full_url = apply_path_params(e_url, path_params)
+        if with_custom_headers:
+            json_data = self._session.put(endpoint_full_url, params=_params,
+                                          json=_payload,
+                                          headers=_headers)
+        else:
+            json_data = self._session.put(endpoint_full_url, params=_params,
+                                          json=_payload)
+
+        return self._object_factory('bpm_398668874439a41d_v1_3_3', json_data)
+
+    def create_application_set(self,
+                               headers=None,
+                               payload=None,
+                               active_validation=True,
+                               **request_parameters):
+        """Create new custom application-set/s.
+
+        Args:
+            headers(dict): Dictionary of HTTP Headers to send with the Request
+                .
+            payload(list): A JSON serializable Python object to send in the
+                body of the Request.
+            active_validation(bool): Enable/Disable payload validation.
+                Defaults to True.
+            **request_parameters: Additional request parameters (provides
+                support for parameters that may be added in the future).
+
+        Returns:
+            MyDict: JSON response. Access the object's properties by using
+            the dot notation or the bracket notation.
+
+        Raises:
+            TypeError: If the parameter types are incorrect.
+            MalformedRequest: If the request body created is invalid.
+            ApiError: If the DNA Center cloud returns an error.
+        """
+        check_type(headers, dict)
+        check_type(payload, list)
+        if headers is not None:
+            if 'X-Auth-Token' in headers:
+                check_type(headers.get('X-Auth-Token'),
+                           basestring, may_be_none=False)
+
+        _params = {
+        }
+        _params.update(request_parameters)
+        _params = dict_from_items_with_values(_params)
+
+        path_params = {
+        }
+
+        _payload = payload or []
+        if active_validation:
+            self._request_validator('jsd_3e94cb1b485b8b0e_v1_3_3')\
+                .validate(_payload)
+
+        with_custom_headers = False
+        _headers = self._session.headers or {}
+        if headers:
+            _headers.update(dict_of_str(headers))
+            with_custom_headers = True
+
+        e_url = ('/dna/intent/api/v1/application-policy-application-set')
+        endpoint_full_url = apply_path_params(e_url, path_params)
+        if with_custom_headers:
+            json_data = self._session.post(endpoint_full_url, params=_params,
+                                           json=_payload,
+                                           headers=_headers)
+        else:
+            json_data = self._session.post(endpoint_full_url, params=_params,
+                                           json=_payload)
+
+        return self._object_factory('bpm_3e94cb1b485b8b0e_v1_3_3', json_data)
+
+    def delete_application_set(self,
+                               id,
+                               headers=None,
+                               **request_parameters):
+        """Delete existing application-set by it's id.
+
+        Args:
+            id(basestring): id query parameter.
+            headers(dict): Dictionary of HTTP Headers to send with the Request
+                .
+            **request_parameters: Additional request parameters (provides
+                support for parameters that may be added in the future).
+
+        Returns:
+            MyDict: JSON response. Access the object's properties by using
+            the dot notation or the bracket notation.
+
+        Raises:
+            TypeError: If the parameter types are incorrect.
+            MalformedRequest: If the request body created is invalid.
+            ApiError: If the DNA Center cloud returns an error.
+        """
+        check_type(headers, dict)
+        check_type(id, basestring,
+                   may_be_none=False)
+        if headers is not None:
+            if 'X-Auth-Token' in headers:
+                check_type(headers.get('X-Auth-Token'),
+                           basestring, may_be_none=False)
+
+        _params = {
+            'id':
+                id,
+        }
+        _params.update(request_parameters)
+        _params = dict_from_items_with_values(_params)
+
+        path_params = {
+        }
+
+        with_custom_headers = False
+        _headers = self._session.headers or {}
+        if headers:
+            _headers.update(dict_of_str(headers))
+            with_custom_headers = True
+
+        e_url = ('/dna/intent/api/v1/application-policy-application-set')
+        endpoint_full_url = apply_path_params(e_url, path_params)
+        if with_custom_headers:
+            json_data = self._session.delete(endpoint_full_url, params=_params,
+                                             headers=_headers)
+        else:
+            json_data = self._session.delete(endpoint_full_url, params=_params)
+
+        return self._object_factory('bpm_70b6f8e140b8b784_v1_3_3', json_data)
+
+    def get_applications(self,
+                         limit=500,
+                         name=None,
+                         offset=1,
+                         headers=None,
+                         **request_parameters):
+        """Get applications by offset/limit or by name.
+
+        Args:
+            offset(int): The offset of the first application to be returned.
+            limit(int): The maximum number of applications to be returned.
+            name(basestring): Application's name.
+            headers(dict): Dictionary of HTTP Headers to send with the Request
+                .
+            **request_parameters: Additional request parameters (provides
+                support for parameters that may be added in the future).
+
+        Returns:
+            list: JSON response. A list of MyDict objects.
+            Access the object's properties by using the dot notation
+            or the bracket notation.
+
+        Raises:
+            TypeError: If the parameter types are incorrect.
+            MalformedRequest: If the request body created is invalid.
+            ApiError: If the DNA Center cloud returns an error.
+        """
+        check_type(headers, dict)
+        check_type(offset, int)
+        check_type(limit, int)
+        check_type(name, basestring)
+        if headers is not None:
+            if 'X-Auth-Token' in headers:
+                check_type(headers.get('X-Auth-Token'),
+                           basestring, may_be_none=False)
+
+        _params = {
+            'offset':
+                offset,
+            'limit':
+                limit,
+            'name':
+                name,
+        }
+        _params.update(request_parameters)
+        _params = dict_from_items_with_values(_params)
+
+        path_params = {
+        }
+
+        with_custom_headers = False
+        _headers = self._session.headers or {}
+        if headers:
+            _headers.update(dict_of_str(headers))
+            with_custom_headers = True
+
+        e_url = ('/dna/intent/api/v1/applications')
+        endpoint_full_url = apply_path_params(e_url, path_params)
+        if with_custom_headers:
+            json_data = self._session.get(endpoint_full_url, params=_params,
+                                          headers=_headers)
+        else:
+            json_data = self._session.get(endpoint_full_url, params=_params)
+
+        return self._object_factory('bpm_8893b834445bb29c_v1_3_3', json_data)
+
     def get_application_sets(self,
-                             limit=None,
+                             limit=500,
                              name=None,
-                             offset=None,
+                             offset=1,
                              headers=None,
                              **request_parameters):
-        """Get appllication-sets by offset/limit or by name .
+        """Get appllication-sets by offset/limit or by name.
 
         Args:
             offset(int): offset query parameter.
@@ -135,16 +429,16 @@ class ApplicationPolicy(object):
         else:
             json_data = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_b60dbd805b95030bc2caf345a44b504_v2_2_2_3', json_data)
+        return self._object_factory('bpm_cb868b2142898159_v1_3_3', json_data)
 
-    def delete_application_set(self,
-                               id,
-                               headers=None,
-                               **request_parameters):
-        """Delete existing application-set by it's id .
+    def delete_application(self,
+                           id,
+                           headers=None,
+                           **request_parameters):
+        """Delete existing application by its id.
 
         Args:
-            id(basestring): id query parameter.
+            id(basestring): Application's Id.
             headers(dict): Dictionary of HTTP Headers to send with the Request
                 .
             **request_parameters: Additional request parameters (provides
@@ -183,7 +477,7 @@ class ApplicationPolicy(object):
             _headers.update(dict_of_str(headers))
             with_custom_headers = True
 
-        e_url = ('/dna/intent/api/v1/application-policy-application-set')
+        e_url = ('/dna/intent/api/v1/applications')
         endpoint_full_url = apply_path_params(e_url, path_params)
         if with_custom_headers:
             json_data = self._session.delete(endpoint_full_url, params=_params,
@@ -191,75 +485,12 @@ class ApplicationPolicy(object):
         else:
             json_data = self._session.delete(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_a59a448c5c25f1e8246d6827e6e3215_v2_2_2_3', json_data)
-
-    def create_application_set(self,
-                               headers=None,
-                               payload=None,
-                               active_validation=True,
-                               **request_parameters):
-        """Create new custom application-set/s .
-
-        Args:
-            headers(dict): Dictionary of HTTP Headers to send with the Request
-                .
-            payload(list): A JSON serializable Python object to send in the
-                body of the Request.
-            active_validation(bool): Enable/Disable payload validation.
-                Defaults to True.
-            **request_parameters: Additional request parameters (provides
-                support for parameters that may be added in the future).
-
-        Returns:
-            MyDict: JSON response. Access the object's properties by using
-            the dot notation or the bracket notation.
-
-        Raises:
-            TypeError: If the parameter types are incorrect.
-            MalformedRequest: If the request body created is invalid.
-            ApiError: If the DNA Center cloud returns an error.
-        """
-        check_type(headers, dict)
-        check_type(payload, list)
-        if headers is not None:
-            if 'X-Auth-Token' in headers:
-                check_type(headers.get('X-Auth-Token'),
-                           basestring, may_be_none=False)
-
-        _params = {
-        }
-        _params.update(request_parameters)
-        _params = dict_from_items_with_values(_params)
-
-        path_params = {
-        }
-        _payload = payload or []
-        if active_validation:
-            self._request_validator('jsd_cb7563a5058c4801eb842a74ff61c_v2_2_2_3')\
-                .validate(_payload)
-
-        with_custom_headers = False
-        _headers = self._session.headers or {}
-        if headers:
-            _headers.update(dict_of_str(headers))
-            with_custom_headers = True
-
-        e_url = ('/dna/intent/api/v1/application-policy-application-set')
-        endpoint_full_url = apply_path_params(e_url, path_params)
-        if with_custom_headers:
-            json_data = self._session.post(endpoint_full_url, params=_params,
-                                           json=_payload,
-                                           headers=_headers)
-        else:
-            json_data = self._session.post(endpoint_full_url, params=_params,
-                                           json=_payload)
-
-        return self._object_factory('bpm_cb7563a5058c4801eb842a74ff61c_v2_2_2_3', json_data)
+        return self._object_factory('bpm_d49af9b84c6aa8ea_v1_3_3', json_data)
 
     def get_application_sets_count(self,
                                    headers=None,
                                    **request_parameters):
-        """Get the number of existing application-sets  .
+        """Get the number of existing application-sets .
 
         Args:
             headers(dict): Dictionary of HTTP Headers to send with the Request
@@ -305,14 +536,14 @@ class ApplicationPolicy(object):
         else:
             json_data = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_ebc5880945305adb41253c6e4ffec_v2_2_2_3', json_data)
+        return self._object_factory('bpm_cfa049a644bb8a07_v1_3_3', json_data)
 
     def create_application(self,
                            headers=None,
                            payload=None,
                            active_validation=True,
                            **request_parameters):
-        """Create new Custom application .
+        """Create new Custom application.
 
         Args:
             headers(dict): Dictionary of HTTP Headers to send with the Request
@@ -347,9 +578,10 @@ class ApplicationPolicy(object):
 
         path_params = {
         }
+
         _payload = payload or []
         if active_validation:
-            self._request_validator('jsd_e1781a990c6b5a4b895d56bcfda2b7cb_v2_2_2_3')\
+            self._request_validator('jsd_fb9bf80f491a9851_v1_3_3')\
                 .validate(_payload)
 
         with_custom_headers = False
@@ -368,239 +600,4 @@ class ApplicationPolicy(object):
             json_data = self._session.post(endpoint_full_url, params=_params,
                                            json=_payload)
 
-        return self._object_factory('bpm_e1781a990c6b5a4b895d56bcfda2b7cb_v2_2_2_3', json_data)
-
-    def edit_application(self,
-                         headers=None,
-                         payload=None,
-                         active_validation=True,
-                         **request_parameters):
-        """Edit the attributes of an existing application .
-
-        Args:
-            headers(dict): Dictionary of HTTP Headers to send with the Request
-                .
-            payload(list): A JSON serializable Python object to send in the
-                body of the Request.
-            active_validation(bool): Enable/Disable payload validation.
-                Defaults to True.
-            **request_parameters: Additional request parameters (provides
-                support for parameters that may be added in the future).
-
-        Returns:
-            MyDict: JSON response. Access the object's properties by using
-            the dot notation or the bracket notation.
-
-        Raises:
-            TypeError: If the parameter types are incorrect.
-            MalformedRequest: If the request body created is invalid.
-            ApiError: If the DNA Center cloud returns an error.
-        """
-        check_type(headers, dict)
-        check_type(payload, list)
-        if headers is not None:
-            if 'X-Auth-Token' in headers:
-                check_type(headers.get('X-Auth-Token'),
-                           basestring, may_be_none=False)
-
-        _params = {
-        }
-        _params.update(request_parameters)
-        _params = dict_from_items_with_values(_params)
-
-        path_params = {
-        }
-        _payload = payload or []
-        if active_validation:
-            self._request_validator('jsd_a3b37dcbe2a150bea06d9dcde1837281_v2_2_2_3')\
-                .validate(_payload)
-
-        with_custom_headers = False
-        _headers = self._session.headers or {}
-        if headers:
-            _headers.update(dict_of_str(headers))
-            with_custom_headers = True
-
-        e_url = ('/dna/intent/api/v1/applications')
-        endpoint_full_url = apply_path_params(e_url, path_params)
-        if with_custom_headers:
-            json_data = self._session.put(endpoint_full_url, params=_params,
-                                          json=_payload,
-                                          headers=_headers)
-        else:
-            json_data = self._session.put(endpoint_full_url, params=_params,
-                                          json=_payload)
-
-        return self._object_factory('bpm_a3b37dcbe2a150bea06d9dcde1837281_v2_2_2_3', json_data)
-
-    def delete_application(self,
-                           id,
-                           headers=None,
-                           **request_parameters):
-        """Delete existing application by its id .
-
-        Args:
-            id(basestring): id query parameter. Application's Id .
-            headers(dict): Dictionary of HTTP Headers to send with the Request
-                .
-            **request_parameters: Additional request parameters (provides
-                support for parameters that may be added in the future).
-
-        Returns:
-            MyDict: JSON response. Access the object's properties by using
-            the dot notation or the bracket notation.
-
-        Raises:
-            TypeError: If the parameter types are incorrect.
-            MalformedRequest: If the request body created is invalid.
-            ApiError: If the DNA Center cloud returns an error.
-        """
-        check_type(headers, dict)
-        check_type(id, basestring,
-                   may_be_none=False)
-        if headers is not None:
-            if 'X-Auth-Token' in headers:
-                check_type(headers.get('X-Auth-Token'),
-                           basestring, may_be_none=False)
-
-        _params = {
-            'id':
-                id,
-        }
-        _params.update(request_parameters)
-        _params = dict_from_items_with_values(_params)
-
-        path_params = {
-        }
-
-        with_custom_headers = False
-        _headers = self._session.headers or {}
-        if headers:
-            _headers.update(dict_of_str(headers))
-            with_custom_headers = True
-
-        e_url = ('/dna/intent/api/v1/applications')
-        endpoint_full_url = apply_path_params(e_url, path_params)
-        if with_custom_headers:
-            json_data = self._session.delete(endpoint_full_url, params=_params,
-                                             headers=_headers)
-        else:
-            json_data = self._session.delete(endpoint_full_url, params=_params)
-
-        return self._object_factory('bpm_d11d35f3505652b68905ddf1ee2f7e66_v2_2_2_3', json_data)
-
-    def get_applications(self,
-                         limit=None,
-                         name=None,
-                         offset=None,
-                         headers=None,
-                         **request_parameters):
-        """Get applications by offset/limit or by name .
-
-        Args:
-            offset(int): offset query parameter. The offset of the first application to be returned .
-            limit(int): limit query parameter. The maximum number of applications to be returned .
-            name(basestring): name query parameter. Application's name .
-            headers(dict): Dictionary of HTTP Headers to send with the Request
-                .
-            **request_parameters: Additional request parameters (provides
-                support for parameters that may be added in the future).
-
-        Returns:
-            list: JSON response. A list of MyDict objects.
-            Access the object's properties by using the dot notation
-            or the bracket notation.
-
-        Raises:
-            TypeError: If the parameter types are incorrect.
-            MalformedRequest: If the request body created is invalid.
-            ApiError: If the DNA Center cloud returns an error.
-        """
-        check_type(headers, dict)
-        check_type(offset, int)
-        check_type(limit, int)
-        check_type(name, basestring)
-        if headers is not None:
-            if 'X-Auth-Token' in headers:
-                check_type(headers.get('X-Auth-Token'),
-                           basestring, may_be_none=False)
-
-        _params = {
-            'offset':
-                offset,
-            'limit':
-                limit,
-            'name':
-                name,
-        }
-        _params.update(request_parameters)
-        _params = dict_from_items_with_values(_params)
-
-        path_params = {
-        }
-
-        with_custom_headers = False
-        _headers = self._session.headers or {}
-        if headers:
-            _headers.update(dict_of_str(headers))
-            with_custom_headers = True
-
-        e_url = ('/dna/intent/api/v1/applications')
-        endpoint_full_url = apply_path_params(e_url, path_params)
-        if with_custom_headers:
-            json_data = self._session.get(endpoint_full_url, params=_params,
-                                          headers=_headers)
-        else:
-            json_data = self._session.get(endpoint_full_url, params=_params)
-
-        return self._object_factory('bpm_b12cdd3a75c51258c9e051e84189f92_v2_2_2_3', json_data)
-
-    def get_applications_count(self,
-                               headers=None,
-                               **request_parameters):
-        """Get the number of all existing applications .
-
-        Args:
-            headers(dict): Dictionary of HTTP Headers to send with the Request
-                .
-            **request_parameters: Additional request parameters (provides
-                support for parameters that may be added in the future).
-
-        Returns:
-            MyDict: JSON response. Access the object's properties by using
-            the dot notation or the bracket notation.
-
-        Raises:
-            TypeError: If the parameter types are incorrect.
-            MalformedRequest: If the request body created is invalid.
-            ApiError: If the DNA Center cloud returns an error.
-        """
-        check_type(headers, dict)
-        if headers is not None:
-            if 'X-Auth-Token' in headers:
-                check_type(headers.get('X-Auth-Token'),
-                           basestring, may_be_none=False)
-
-        _params = {
-        }
-        _params.update(request_parameters)
-        _params = dict_from_items_with_values(_params)
-
-        path_params = {
-        }
-
-        with_custom_headers = False
-        _headers = self._session.headers or {}
-        if headers:
-            _headers.update(dict_of_str(headers))
-            with_custom_headers = True
-
-        e_url = ('/dna/intent/api/v1/applications-count')
-        endpoint_full_url = apply_path_params(e_url, path_params)
-        if with_custom_headers:
-            json_data = self._session.get(endpoint_full_url, params=_params,
-                                          headers=_headers)
-        else:
-            json_data = self._session.get(endpoint_full_url, params=_params)
-
-        return self._object_factory('bpm_af5f0aa1ed56ab9b98eb602dbd8366_v2_2_2_3', json_data)
+        return self._object_factory('bpm_fb9bf80f491a9851_v1_3_3', json_data)
