@@ -22,13 +22,7 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 
-
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-    unicode_literals,
-)
+from __future__ import absolute_import, division, print_function, unicode_literals
 
 from builtins import *
 
@@ -36,15 +30,15 @@ from past.builtins import basestring
 
 from ...restsession import RestSession
 from ...utils import (
+    apply_path_params,
     check_type,
     dict_from_items_with_values,
-    apply_path_params,
     dict_of_str,
 )
 
 
 class Wireless(object):
-    """Cisco DNA Center Wireless API (version: 2.1.2).
+    """Cisco DNA Center Wireless API (version: 1.3.3).
 
     Wraps the DNA Center Wireless
     API and exposes the API as native Python
@@ -125,7 +119,7 @@ class Wireless(object):
         else:
             json_data = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_098cab9141c9a3fe_v2_1_2', json_data)
+        return self._object_factory('bpm_098cab9141c9a3fe_v1_3_3', json_data)
 
     def create_and_provision_ssid(self,
                                   enableFabric=None,
@@ -200,7 +194,7 @@ class Wireless(object):
         _payload.update(payload or {})
         _payload = dict_from_items_with_values(_payload)
         if active_validation:
-            self._request_validator('jsd_1eb72ad34e098990_v2_1_2')\
+            self._request_validator('jsd_1eb72ad34e098990_v1_3_3')\
                 .validate(_payload)
 
         with_custom_headers = False
@@ -219,7 +213,7 @@ class Wireless(object):
             json_data = self._session.post(endpoint_full_url, params=_params,
                                            json=_payload)
 
-        return self._object_factory('bpm_1eb72ad34e098990_v2_1_2', json_data)
+        return self._object_factory('bpm_1eb72ad34e098990_v1_3_3', json_data)
 
     def delete_rf_profiles(self,
                            rf_profile_name,
@@ -275,7 +269,7 @@ class Wireless(object):
         else:
             json_data = self._session.delete(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_28b24a744a9994be_v2_1_2', json_data)
+        return self._object_factory('bpm_28b24a744a9994be_v1_3_3', json_data)
 
     def create_wireless_profile(self,
                                 profileDetails=None,
@@ -328,7 +322,7 @@ class Wireless(object):
         _payload.update(payload or {})
         _payload = dict_from_items_with_values(_payload)
         if active_validation:
-            self._request_validator('jsd_709769624bf988d5_v2_1_2')\
+            self._request_validator('jsd_709769624bf988d5_v1_3_3')\
                 .validate(_payload)
 
         with_custom_headers = False
@@ -347,24 +341,22 @@ class Wireless(object):
             json_data = self._session.post(endpoint_full_url, params=_params,
                                            json=_payload)
 
-        return self._object_factory('bpm_709769624bf988d5_v2_1_2', json_data)
+        return self._object_factory('bpm_709769624bf988d5_v1_3_3', json_data)
 
-    def sensor_test_results(self,
-                            end_time=None,
-                            site_id=None,
-                            start_time=None,
-                            test_failure_by='area',
-                            headers=None,
-                            **request_parameters):
-        """Intent API to get SENSOR test result summary.
+    def provision_update(self,
+                         headers=None,
+                         payload=None,
+                         active_validation=True,
+                         **request_parameters):
+        """Updates wireless provisioning.
 
         Args:
-            site_id(basestring): Assurance site UUID.
-            start_time(int): The epoch time in milliseconds.
-            end_time(int): The epoch time in milliseconds.
-            test_failure_by(basestring): Obtain failure statistics group by "area", "building", or "floor".
             headers(dict): Dictionary of HTTP Headers to send with the Request
                 .
+            payload(list): A JSON serializable Python object to send in the
+                body of the Request.
+            active_validation(bool): Enable/Disable payload validation.
+                Defaults to True.
             **request_parameters: Additional request parameters (provides
                 support for parameters that may be added in the future).
 
@@ -378,24 +370,16 @@ class Wireless(object):
             ApiError: If the DNA Center cloud returns an error.
         """
         check_type(headers, dict)
-        check_type(site_id, basestring)
-        check_type(start_time, int)
-        check_type(end_time, int)
-        check_type(test_failure_by, basestring)
+        check_type(payload, list)
         if headers is not None:
+            if '__persistbapioutput' in headers:
+                check_type(headers.get('__persistbapioutput'),
+                           basestring, may_be_none=False)
             if 'X-Auth-Token' in headers:
                 check_type(headers.get('X-Auth-Token'),
                            basestring, may_be_none=False)
 
         _params = {
-            'siteId':
-                site_id,
-            'startTime':
-                start_time,
-            'endTime':
-                end_time,
-            'testFailureBy':
-                test_failure_by,
         }
         _params.update(request_parameters)
         _params = dict_from_items_with_values(_params)
@@ -403,21 +387,28 @@ class Wireless(object):
         path_params = {
         }
 
+        _payload = payload or []
+        if active_validation:
+            self._request_validator('jsd_87a5ab044139862d_v1_3_3')\
+                .validate(_payload)
+
         with_custom_headers = False
         _headers = self._session.headers or {}
         if headers:
             _headers.update(dict_of_str(headers))
             with_custom_headers = True
 
-        e_url = ('/dna/intent/api/v1/AssuranceGetSensorTestResults')
+        e_url = ('/dna/intent/api/v1/wireless/provision')
         endpoint_full_url = apply_path_params(e_url, path_params)
         if with_custom_headers:
-            json_data = self._session.get(endpoint_full_url, params=_params,
+            json_data = self._session.put(endpoint_full_url, params=_params,
+                                          json=_payload,
                                           headers=_headers)
         else:
-            json_data = self._session.get(endpoint_full_url, params=_params)
+            json_data = self._session.put(endpoint_full_url, params=_params,
+                                          json=_payload)
 
-        return self._object_factory('bpm_87ae7b214f0ba838_v2_1_2', json_data)
+        return self._object_factory('bpm_87a5ab044139862d_v1_3_3', json_data)
 
     def create_enterprise_ssid(self,
                                enableBroadcastSSID=None,
@@ -507,7 +498,7 @@ class Wireless(object):
         _payload.update(payload or {})
         _payload = dict_from_items_with_values(_payload)
         if active_validation:
-            self._request_validator('jsd_8a96fb954d09a349_v2_1_2')\
+            self._request_validator('jsd_8a96fb954d09a349_v1_3_3')\
                 .validate(_payload)
 
         with_custom_headers = False
@@ -526,7 +517,7 @@ class Wireless(object):
             json_data = self._session.post(endpoint_full_url, params=_params,
                                            json=_payload)
 
-        return self._object_factory('bpm_8a96fb954d09a349_v2_1_2', json_data)
+        return self._object_factory('bpm_8a96fb954d09a349_v1_3_3', json_data)
 
     def get_wireless_profile(self,
                              profile_name=None,
@@ -583,7 +574,7 @@ class Wireless(object):
         else:
             json_data = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_b3a1c8804c8b9b8b_v2_1_2', json_data)
+        return self._object_factory('bpm_b3a1c8804c8b9b8b_v1_3_3', json_data)
 
     def create_or_update_rf_profile(self,
                                     channelWidth=None,
@@ -667,7 +658,7 @@ class Wireless(object):
         _payload.update(payload or {})
         _payload = dict_from_items_with_values(_payload)
         if active_validation:
-            self._request_validator('jsd_b78329674878b815_v2_1_2')\
+            self._request_validator('jsd_b78329674878b815_v1_3_3')\
                 .validate(_payload)
 
         with_custom_headers = False
@@ -686,7 +677,7 @@ class Wireless(object):
             json_data = self._session.post(endpoint_full_url, params=_params,
                                            json=_payload)
 
-        return self._object_factory('bpm_b78329674878b815_v2_1_2', json_data)
+        return self._object_factory('bpm_b78329674878b815_v1_3_3', json_data)
 
     def delete_enterprise_ssid(self,
                                ssid_name,
@@ -741,74 +732,7 @@ class Wireless(object):
         else:
             json_data = self._session.delete(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_c7a6592b4b98a369_v2_1_2', json_data)
-
-    def provision_update(self,
-                         headers=None,
-                         payload=None,
-                         active_validation=True,
-                         **request_parameters):
-        """Updates wireless provisioning.
-
-        Args:
-            headers(dict): Dictionary of HTTP Headers to send with the Request
-                .
-            payload(list): A JSON serializable Python object to send in the
-                body of the Request.
-            active_validation(bool): Enable/Disable payload validation.
-                Defaults to True.
-            **request_parameters: Additional request parameters (provides
-                support for parameters that may be added in the future).
-
-        Returns:
-            MyDict: JSON response. Access the object's properties by using
-            the dot notation or the bracket notation.
-
-        Raises:
-            TypeError: If the parameter types are incorrect.
-            MalformedRequest: If the request body created is invalid.
-            ApiError: If the DNA Center cloud returns an error.
-        """
-        check_type(headers, dict)
-        check_type(payload, list)
-        if headers is not None:
-            if '__persistbapioutput' in headers:
-                check_type(headers.get('__persistbapioutput'),
-                           basestring, may_be_none=False)
-            if 'X-Auth-Token' in headers:
-                check_type(headers.get('X-Auth-Token'),
-                           basestring, may_be_none=False)
-
-        _params = {
-        }
-        _params.update(request_parameters)
-        _params = dict_from_items_with_values(_params)
-
-        path_params = {
-        }
-
-        _payload = payload or []
-        if active_validation:
-            self._request_validator('jsd_87a5ab044139862d_v2_1_2')\
-                .validate(_payload)
-
-        with_custom_headers = False
-        _headers = self._session.headers or {}
-        if headers:
-            _headers.update(dict_of_str(headers))
-            with_custom_headers = True
-
-        e_url = ('/dna/intent/api/v1/wireless/provision')
-        endpoint_full_url = apply_path_params(e_url, path_params)
-        if with_custom_headers:
-            json_data = self._session.put(endpoint_full_url, params=_params,
-                                          json=_payload,
-                                          headers=_headers)
-        else:
-            json_data = self._session.put(endpoint_full_url, params=_params,
-                                          json=_payload)
-
-        return self._object_factory('bpm_87a5ab044139862d_v2_1_2', json_data)
+        return self._object_factory('bpm_c7a6592b4b98a369_v1_3_3', json_data)
 
     def get_enterprise_ssid(self,
                             ssid_name=None,
@@ -865,7 +789,7 @@ class Wireless(object):
         else:
             json_data = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_cca519ba45ebb423_v2_1_2', json_data)
+        return self._object_factory('bpm_cca519ba45ebb423_v1_3_3', json_data)
 
     def provision(self,
                   headers=None,
@@ -913,7 +837,7 @@ class Wireless(object):
 
         _payload = payload or []
         if active_validation:
-            self._request_validator('jsd_d09b08a3447aa3b9_v2_1_2')\
+            self._request_validator('jsd_d09b08a3447aa3b9_v1_3_3')\
                 .validate(_payload)
 
         with_custom_headers = False
@@ -932,7 +856,80 @@ class Wireless(object):
             json_data = self._session.post(endpoint_full_url, params=_params,
                                            json=_payload)
 
-        return self._object_factory('bpm_d09b08a3447aa3b9_v2_1_2', json_data)
+        return self._object_factory('bpm_d09b08a3447aa3b9_v1_3_3', json_data)
+
+    def update_wireless_profile(self,
+                                profileDetails=None,
+                                headers=None,
+                                payload=None,
+                                active_validation=True,
+                                **request_parameters):
+        """Updates the wireless Network Profile with updated details
+        provided. All sites to be present in the network profile
+        should be provided.
+
+        Args:
+            profileDetails(object): Profile Details, property of the request body.
+            headers(dict): Dictionary of HTTP Headers to send with the Request
+                .
+            payload(dict): A JSON serializable Python object to send in the
+                body of the Request.
+            active_validation(bool): Enable/Disable payload validation.
+                Defaults to True.
+            **request_parameters: Additional request parameters (provides
+                support for parameters that may be added in the future).
+
+        Returns:
+            MyDict: JSON response. Access the object's properties by using
+            the dot notation or the bracket notation.
+
+        Raises:
+            TypeError: If the parameter types are incorrect.
+            MalformedRequest: If the request body created is invalid.
+            ApiError: If the DNA Center cloud returns an error.
+        """
+        check_type(headers, dict)
+        check_type(payload, dict)
+        if headers is not None:
+            if 'X-Auth-Token' in headers:
+                check_type(headers.get('X-Auth-Token'),
+                           basestring, may_be_none=False)
+
+        _params = {
+        }
+        _params.update(request_parameters)
+        _params = dict_from_items_with_values(_params)
+
+        path_params = {
+        }
+
+        _payload = {
+            'profileDetails':
+                profileDetails,
+        }
+        _payload.update(payload or {})
+        _payload = dict_from_items_with_values(_payload)
+        if active_validation:
+            self._request_validator('jsd_cfbd3870405aad55_v1_3_3')\
+                .validate(_payload)
+
+        with_custom_headers = False
+        _headers = self._session.headers or {}
+        if headers:
+            _headers.update(dict_of_str(headers))
+            with_custom_headers = True
+
+        e_url = ('/dna/intent/api/v1/wireless/profile')
+        endpoint_full_url = apply_path_params(e_url, path_params)
+        if with_custom_headers:
+            json_data = self._session.put(endpoint_full_url, params=_params,
+                                          json=_payload,
+                                          headers=_headers)
+        else:
+            json_data = self._session.put(endpoint_full_url, params=_params,
+                                          json=_payload)
+
+        return self._object_factory('bpm_cfbd3870405aad55_v1_3_3', json_data)
 
     def ap_provision(self,
                      headers=None,
@@ -980,7 +977,7 @@ class Wireless(object):
 
         _payload = payload or []
         if active_validation:
-            self._request_validator('jsd_e9b99b2248c88014_v2_1_2')\
+            self._request_validator('jsd_e9b99b2248c88014_v1_3_3')\
                 .validate(_payload)
 
         with_custom_headers = False
@@ -999,7 +996,7 @@ class Wireless(object):
             json_data = self._session.post(endpoint_full_url, params=_params,
                                            json=_payload)
 
-        return self._object_factory('bpm_e9b99b2248c88014_v2_1_2', json_data)
+        return self._object_factory('bpm_e9b99b2248c88014_v1_3_3', json_data)
 
     def delete_wireless_profile(self,
                                 wireless_profile_name,
@@ -1055,80 +1052,7 @@ class Wireless(object):
         else:
             json_data = self._session.delete(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_e39588a5494982c4_v2_1_2', json_data)
-
-    def update_wireless_profile(self,
-                                profileDetails=None,
-                                headers=None,
-                                payload=None,
-                                active_validation=True,
-                                **request_parameters):
-        """Updates the wireless Network Profile with updated details
-        provided. All sites to be present in the network profile
-        should be provided.
-
-        Args:
-            profileDetails(object): Profile Details, property of the request body.
-            headers(dict): Dictionary of HTTP Headers to send with the Request
-                .
-            payload(dict): A JSON serializable Python object to send in the
-                body of the Request.
-            active_validation(bool): Enable/Disable payload validation.
-                Defaults to True.
-            **request_parameters: Additional request parameters (provides
-                support for parameters that may be added in the future).
-
-        Returns:
-            MyDict: JSON response. Access the object's properties by using
-            the dot notation or the bracket notation.
-
-        Raises:
-            TypeError: If the parameter types are incorrect.
-            MalformedRequest: If the request body created is invalid.
-            ApiError: If the DNA Center cloud returns an error.
-        """
-        check_type(headers, dict)
-        check_type(payload, dict)
-        if headers is not None:
-            if 'X-Auth-Token' in headers:
-                check_type(headers.get('X-Auth-Token'),
-                           basestring, may_be_none=False)
-
-        _params = {
-        }
-        _params.update(request_parameters)
-        _params = dict_from_items_with_values(_params)
-
-        path_params = {
-        }
-
-        _payload = {
-            'profileDetails':
-                profileDetails,
-        }
-        _payload.update(payload or {})
-        _payload = dict_from_items_with_values(_payload)
-        if active_validation:
-            self._request_validator('jsd_cfbd3870405aad55_v2_1_2')\
-                .validate(_payload)
-
-        with_custom_headers = False
-        _headers = self._session.headers or {}
-        if headers:
-            _headers.update(dict_of_str(headers))
-            with_custom_headers = True
-
-        e_url = ('/dna/intent/api/v1/wireless/profile')
-        endpoint_full_url = apply_path_params(e_url, path_params)
-        if with_custom_headers:
-            json_data = self._session.put(endpoint_full_url, params=_params,
-                                          json=_payload,
-                                          headers=_headers)
-        else:
-            json_data = self._session.put(endpoint_full_url, params=_params,
-                                          json=_payload)
-
-        return self._object_factory('bpm_cfbd3870405aad55_v2_1_2', json_data)
+        return self._object_factory('bpm_e39588a5494982c4_v1_3_3', json_data)
 
     def delete_ssid_and_provision_it_to_devices(self,
                                                 managed_aplocations,
@@ -1193,4 +1117,4 @@ class Wireless(object):
         else:
             json_data = self._session.delete(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_fc9538fe43d9884d_v2_1_2', json_data)
+        return self._object_factory('bpm_fc9538fe43d9884d_v1_3_3', json_data)
