@@ -22,13 +22,7 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 
-
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-    unicode_literals,
-)
+from __future__ import absolute_import, division, print_function, unicode_literals
 
 from builtins import *
 
@@ -36,15 +30,15 @@ from past.builtins import basestring
 
 from ...restsession import RestSession
 from ...utils import (
+    apply_path_params,
     check_type,
     dict_from_items_with_values,
-    apply_path_params,
     dict_of_str,
 )
 
 
 class SiteDesign(object):
-    """Cisco DNA Center Site Design API (version: 2.1.2).
+    """Cisco DNA Center Site Design API (version: 2.1.1).
 
     Wraps the DNA Center Site Design
     API and exposes the API as native Python
@@ -140,7 +134,7 @@ class SiteDesign(object):
         else:
             json_data = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_1eb19887457b9616_v2_1_2', json_data)
+        return self._object_factory('bpm_1eb19887457b9616_v2_1_1', json_data)
 
     def update_nfv_profile(self,
                            id,
@@ -202,7 +196,7 @@ class SiteDesign(object):
         _payload.update(payload or {})
         _payload = dict_from_items_with_values(_payload)
         if active_validation:
-            self._request_validator('jsd_0fa00adf48698287_v2_1_2')\
+            self._request_validator('jsd_0fa00adf48698287_v2_1_1')\
                 .validate(_payload)
 
         with_custom_headers = False
@@ -221,82 +215,7 @@ class SiteDesign(object):
             json_data = self._session.put(endpoint_full_url, params=_params,
                                           json=_payload)
 
-        return self._object_factory('bpm_0fa00adf48698287_v2_1_2', json_data)
-
-    def create_nfv_profile(self,
-                           device=None,
-                           profileName=None,
-                           headers=None,
-                           payload=None,
-                           active_validation=True,
-                           **request_parameters):
-        """API to create network profile for different NFV topologies.
-
-        Args:
-            device(list): Device, property of the request body (list of objects).
-            profileName(string): Site Profile Name, property of the request body.
-            headers(dict): Dictionary of HTTP Headers to send with the Request
-                .
-            payload(dict): A JSON serializable Python object to send in the
-                body of the Request.
-            active_validation(bool): Enable/Disable payload validation.
-                Defaults to True.
-            **request_parameters: Additional request parameters (provides
-                support for parameters that may be added in the future).
-
-        Returns:
-            MyDict: JSON response. Access the object's properties by using
-            the dot notation or the bracket notation.
-
-        Raises:
-            TypeError: If the parameter types are incorrect.
-            MalformedRequest: If the request body created is invalid.
-            ApiError: If the DNA Center cloud returns an error.
-        """
-        check_type(headers, dict)
-        check_type(payload, dict)
-        if headers is not None:
-            if 'X-Auth-Token' in headers:
-                check_type(headers.get('X-Auth-Token'),
-                           basestring, may_be_none=False)
-
-        _params = {
-        }
-        _params.update(request_parameters)
-        _params = dict_from_items_with_values(_params)
-
-        path_params = {
-        }
-
-        _payload = {
-            'profileName':
-                profileName,
-            'device':
-                device,
-        }
-        _payload.update(payload or {})
-        _payload = dict_from_items_with_values(_payload)
-        if active_validation:
-            self._request_validator('jsd_66951aaa407ba89c_v2_1_2')\
-                .validate(_payload)
-
-        with_custom_headers = False
-        _headers = self._session.headers or {}
-        if headers:
-            _headers.update(dict_of_str(headers))
-            with_custom_headers = True
-
-        e_url = ('/dna/intent/api/v1/nfv/network-profile')
-        endpoint_full_url = apply_path_params(e_url, path_params)
-        if with_custom_headers:
-            json_data = self._session.post(endpoint_full_url, params=_params,
-                                           json=_payload,
-                                           headers=_headers)
-        else:
-            json_data = self._session.post(endpoint_full_url, params=_params,
-                                           json=_payload)
-
-        return self._object_factory('bpm_66951aaa407ba89c_v2_1_2', json_data)
+        return self._object_factory('bpm_0fa00adf48698287_v2_1_1', json_data)
 
     def nfv_provisioning_detail(self,
                                 device_ip=None,
@@ -358,7 +277,7 @@ class SiteDesign(object):
         _payload.update(payload or {})
         _payload = dict_from_items_with_values(_payload)
         if active_validation:
-            self._request_validator('jsd_2f97e8fa45f8b2a3_v2_1_2')\
+            self._request_validator('jsd_2f97e8fa45f8b2a3_v2_1_1')\
                 .validate(_payload)
 
         with_custom_headers = False
@@ -377,7 +296,7 @@ class SiteDesign(object):
             json_data = self._session.post(endpoint_full_url, params=_params,
                                            json=_payload)
 
-        return self._object_factory('bpm_2f97e8fa45f8b2a3_v2_1_2', json_data)
+        return self._object_factory('bpm_2f97e8fa45f8b2a3_v2_1_1', json_data)
 
     def delete_nfv_profile(self,
                            id,
@@ -437,7 +356,82 @@ class SiteDesign(object):
         else:
             json_data = self._session.delete(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_5ebbfa2541b8b8a9_v2_1_2', json_data)
+        return self._object_factory('bpm_5ebbfa2541b8b8a9_v2_1_1', json_data)
+
+    def create_nfv_profile(self,
+                           device=None,
+                           profileName=None,
+                           headers=None,
+                           payload=None,
+                           active_validation=True,
+                           **request_parameters):
+        """API to create network profile for different NFV topologies.
+
+        Args:
+            device(list): Device, property of the request body (list of objects).
+            profileName(string): Site Profile Name, property of the request body.
+            headers(dict): Dictionary of HTTP Headers to send with the Request
+                .
+            payload(dict): A JSON serializable Python object to send in the
+                body of the Request.
+            active_validation(bool): Enable/Disable payload validation.
+                Defaults to True.
+            **request_parameters: Additional request parameters (provides
+                support for parameters that may be added in the future).
+
+        Returns:
+            MyDict: JSON response. Access the object's properties by using
+            the dot notation or the bracket notation.
+
+        Raises:
+            TypeError: If the parameter types are incorrect.
+            MalformedRequest: If the request body created is invalid.
+            ApiError: If the DNA Center cloud returns an error.
+        """
+        check_type(headers, dict)
+        check_type(payload, dict)
+        if headers is not None:
+            if 'X-Auth-Token' in headers:
+                check_type(headers.get('X-Auth-Token'),
+                           basestring, may_be_none=False)
+
+        _params = {
+        }
+        _params.update(request_parameters)
+        _params = dict_from_items_with_values(_params)
+
+        path_params = {
+        }
+
+        _payload = {
+            'profileName':
+                profileName,
+            'device':
+                device,
+        }
+        _payload.update(payload or {})
+        _payload = dict_from_items_with_values(_payload)
+        if active_validation:
+            self._request_validator('jsd_66951aaa407ba89c_v2_1_1')\
+                .validate(_payload)
+
+        with_custom_headers = False
+        _headers = self._session.headers or {}
+        if headers:
+            _headers.update(dict_of_str(headers))
+            with_custom_headers = True
+
+        e_url = ('/dna/intent/api/v1/nfv/network-profile')
+        endpoint_full_url = apply_path_params(e_url, path_params)
+        if with_custom_headers:
+            json_data = self._session.post(endpoint_full_url, params=_params,
+                                           json=_payload,
+                                           headers=_headers)
+        else:
+            json_data = self._session.post(endpoint_full_url, params=_params,
+                                           json=_payload)
+
+        return self._object_factory('bpm_66951aaa407ba89c_v2_1_1', json_data)
 
     def provision_nfv(self,
                       provisioning=None,
@@ -503,7 +497,7 @@ class SiteDesign(object):
         _payload.update(payload or {})
         _payload = dict_from_items_with_values(_payload)
         if active_validation:
-            self._request_validator('jsd_6f9cda9a465884b4_v2_1_2')\
+            self._request_validator('jsd_6f9cda9a465884b4_v2_1_1')\
                 .validate(_payload)
 
         with_custom_headers = False
@@ -522,7 +516,7 @@ class SiteDesign(object):
             json_data = self._session.post(endpoint_full_url, params=_params,
                                            json=_payload)
 
-        return self._object_factory('bpm_6f9cda9a465884b4_v2_1_2', json_data)
+        return self._object_factory('bpm_6f9cda9a465884b4_v2_1_1', json_data)
 
     def get_device_details_by_ip(self,
                                  device_ip,
@@ -579,4 +573,4 @@ class SiteDesign(object):
         else:
             json_data = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_9cb2cb3f494a824f_v2_1_2', json_data)
+        return self._object_factory('bpm_9cb2cb3f494a824f_v2_1_1', json_data)
