@@ -22,13 +22,7 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 
-
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-    unicode_literals,
-)
+from __future__ import absolute_import, division, print_function, unicode_literals
 
 from builtins import *
 
@@ -36,15 +30,15 @@ from past.builtins import basestring
 
 from ...restsession import RestSession
 from ...utils import (
+    apply_path_params,
     check_type,
     dict_from_items_with_values,
-    apply_path_params,
     dict_of_str,
 )
 
 
 class Sites(object):
-    """Cisco DNA Center Sites API (version: 1.3.0).
+    """Cisco DNA Center Sites API (version: 2.1.1).
 
     Wraps the DNA Center Sites
     API and exposes the API as native Python
@@ -72,6 +66,91 @@ class Sites(object):
         self._object_factory = object_factory
         self._request_validator = request_validator
 
+    def assign_device_to_site(self,
+                              site_id,
+                              device=None,
+                              headers=None,
+                              payload=None,
+                              active_validation=True,
+                              **request_parameters):
+        """Assigns list of devices to a site.
+
+        Args:
+            device(list): Device, property of the request body (list of objects).
+            site_id(basestring): Site id to which site the device to assign.
+            headers(dict): Dictionary of HTTP Headers to send with the Request
+                .
+            payload(dict): A JSON serializable Python object to send in the
+                body of the Request.
+            active_validation(bool): Enable/Disable payload validation.
+                Defaults to True.
+            **request_parameters: Additional request parameters (provides
+                support for parameters that may be added in the future).
+
+        Returns:
+            MyDict: JSON response. Access the object's properties by using
+            the dot notation or the bracket notation.
+
+        Raises:
+            TypeError: If the parameter types are incorrect.
+            MalformedRequest: If the request body created is invalid.
+            ApiError: If the DNA Center cloud returns an error.
+        """
+        check_type(headers, dict)
+        check_type(payload, dict)
+        check_type(site_id, basestring,
+                   may_be_none=False)
+        if headers is not None:
+            if '__runsync' in headers:
+                check_type(headers.get('__runsync'),
+                           bool, may_be_none=False)
+            if '__persistbapioutput' in headers:
+                check_type(headers.get('__persistbapioutput'),
+                           bool, may_be_none=False)
+            if '__runsynctimeout' in headers:
+                check_type(headers.get('__runsynctimeout'),
+                           int)
+            if 'X-Auth-Token' in headers:
+                check_type(headers.get('X-Auth-Token'),
+                           basestring, may_be_none=False)
+
+        _params = {
+        }
+        _params.update(request_parameters)
+        _params = dict_from_items_with_values(_params)
+
+        path_params = {
+            'siteId': site_id,
+        }
+
+        _payload = {
+            'device':
+                device,
+        }
+        _payload.update(payload or {})
+        _payload = dict_from_items_with_values(_payload)
+        if active_validation:
+            self._request_validator('jsd_eeb168eb41988e07_v2_1_1')\
+                .validate(_payload)
+
+        with_custom_headers = False
+        _headers = self._session.headers or {}
+        if headers:
+            _headers.update(dict_of_str(headers))
+            with_custom_headers = True
+
+        e_url = ('/dna/system/api/v1/site/${siteId}/device')
+        endpoint_full_url = apply_path_params(e_url, path_params)
+        if with_custom_headers:
+            json_data = self._session.post(endpoint_full_url, params=_params,
+                                           json=_payload,
+                                           headers=_headers)
+        else:
+            json_data = self._session.post(endpoint_full_url, params=_params,
+                                           json=_payload)
+
+        return self._object_factory('bpm_eeb168eb41988e07_v2_1_1', json_data)
+
     def get_site_health(self,
                         timestamp=None,
                         headers=None,
@@ -129,97 +208,7 @@ class Sites(object):
         else:
             json_data = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_17a82ac94cf99ab0_v1_3_0', json_data)
-
-    def update_site(self,
-                    site_id,
-                    site=None,
-                    type=None,
-                    headers=None,
-                    payload=None,
-                    active_validation=True,
-                    **request_parameters):
-        """Update site area/building/floor with specified hierarchy and new
-        values.
-
-        Args:
-            site(object): Site, property of the request body.
-            type(string): Type, property of the request body. Available values are 'area', 'building' and 'floor'.
-            site_id(basestring): site id.
-            headers(dict): Dictionary of HTTP Headers to send with the Request
-                .
-            payload(dict): A JSON serializable Python object to send in the
-                body of the Request.
-            active_validation(bool): Enable/Disable payload validation.
-                Defaults to True.
-            **request_parameters: Additional request parameters (provides
-                support for parameters that may be added in the future).
-
-        Returns:
-            MyDict: JSON response. Access the object's properties by using
-            the dot notation or the bracket notation.
-
-        Raises:
-            TypeError: If the parameter types are incorrect.
-            MalformedRequest: If the request body created is invalid.
-            ApiError: If the DNA Center cloud returns an error.
-        """
-        check_type(headers, dict)
-        check_type(payload, dict)
-        check_type(site_id, basestring,
-                   may_be_none=False)
-        if headers is not None:
-            if '__runsync' in headers:
-                check_type(headers.get('__runsync'),
-                           bool, may_be_none=False)
-            if '__runsynctimeout' in headers:
-                check_type(headers.get('__runsynctimeout'),
-                           int)
-            if '__persistbapioutput' in headers:
-                check_type(headers.get('__persistbapioutput'),
-                           bool, may_be_none=False)
-            if 'X-Auth-Token' in headers:
-                check_type(headers.get('X-Auth-Token'),
-                           basestring, may_be_none=False)
-
-        _params = {
-        }
-        _params.update(request_parameters)
-        _params = dict_from_items_with_values(_params)
-
-        path_params = {
-            'siteId': site_id,
-        }
-
-        _payload = {
-            'type':
-                type,
-            'site':
-                site,
-        }
-        _payload.update(payload or {})
-        _payload = dict_from_items_with_values(_payload)
-        if active_validation:
-            self._request_validator('jsd_33aab9b842388023_v1_3_0')\
-                .validate(_payload)
-
-        with_custom_headers = False
-        _headers = self._session.headers or {}
-        if headers:
-            _headers.update(dict_of_str(headers))
-            with_custom_headers = True
-
-        e_url = ('/dna/intent/api/v1/site/${siteId}')
-        endpoint_full_url = apply_path_params(e_url, path_params)
-        if with_custom_headers:
-            json_data = self._session.put(endpoint_full_url, params=_params,
-                                          json=_payload,
-                                          headers=_headers)
-        else:
-            json_data = self._session.put(endpoint_full_url, params=_params,
-                                          json=_payload)
-
-        return self._object_factory('bpm_33aab9b842388023_v1_3_0', json_data)
+        return self._object_factory('bpm_15b7aa0c4dda8e85_v2_1_1', json_data)
 
     def create_site(self,
                     site=None,
@@ -257,8 +246,8 @@ class Sites(object):
             if '__runsync' in headers:
                 check_type(headers.get('__runsync'),
                            bool, may_be_none=False)
-            if '__runsynctimeout' in headers:
-                check_type(headers.get('__runsynctimeout'),
+            if '__timeout' in headers:
+                check_type(headers.get('__timeout'),
                            int)
             if '__persistbapioutput' in headers:
                 check_type(headers.get('__persistbapioutput'),
@@ -284,7 +273,7 @@ class Sites(object):
         _payload.update(payload or {})
         _payload = dict_from_items_with_values(_payload)
         if active_validation:
-            self._request_validator('jsd_23896b124bd8b9bf_v1_3_0')\
+            self._request_validator('jsd_50b589fd4c7a930a_v2_1_1')\
                 .validate(_payload)
 
         with_custom_headers = False
@@ -303,7 +292,7 @@ class Sites(object):
             json_data = self._session.post(endpoint_full_url, params=_params,
                                            json=_payload)
 
-        return self._object_factory('bpm_23896b124bd8b9bf_v1_3_0', json_data)
+        return self._object_factory('bpm_50b589fd4c7a930a_v2_1_1', json_data)
 
     def get_site(self,
                  limit=None,
@@ -316,11 +305,11 @@ class Sites(object):
         """Get site with area/building/floor with specified hierarchy.
 
         Args:
-            name(basestring): groupNameHierarchy (ex: global/groupName).
-            site_id(basestring): site id.
+            name(basestring): siteNameHierarchy (ex: global/groupName).
+            site_id(basestring): Site id to which site details to retrieve.
             type(basestring): type (ex: area, building, floor).
-            offset(int): offset/starting row.
-            limit(int): Number of sites to be retrieved.
+            offset(basestring): offset/starting row.
+            limit(basestring): Number of sites to be retrieved.
             headers(dict): Dictionary of HTTP Headers to send with the Request
                 .
             **request_parameters: Additional request parameters (provides
@@ -339,18 +328,9 @@ class Sites(object):
         check_type(name, basestring)
         check_type(site_id, basestring)
         check_type(type, basestring)
-        check_type(offset, int)
-        check_type(limit, int)
+        check_type(offset, basestring)
+        check_type(limit, basestring)
         if headers is not None:
-            if '__runsync' in headers:
-                check_type(headers.get('__runsync'),
-                           bool, may_be_none=False)
-            if '__runsynctimeout' in headers:
-                check_type(headers.get('__runsynctimeout'),
-                           int)
-            if '__persistbapioutput' in headers:
-                check_type(headers.get('__persistbapioutput'),
-                           bool, may_be_none=False)
             if 'X-Auth-Token' in headers:
                 check_type(headers.get('X-Auth-Token'),
                            basestring, may_be_none=False)
@@ -387,71 +367,7 @@ class Sites(object):
         else:
             json_data = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_209509d247599e19_v1_3_0', json_data)
-
-    def delete_site(self,
-                    site_id,
-                    headers=None,
-                    **request_parameters):
-        """Delete site with area/building/floor by siteId.
-
-        Args:
-            site_id(basestring): site id.
-            headers(dict): Dictionary of HTTP Headers to send with the Request
-                .
-            **request_parameters: Additional request parameters (provides
-                support for parameters that may be added in the future).
-
-        Returns:
-            MyDict: JSON response. Access the object's properties by using
-            the dot notation or the bracket notation.
-
-        Raises:
-            TypeError: If the parameter types are incorrect.
-            MalformedRequest: If the request body created is invalid.
-            ApiError: If the DNA Center cloud returns an error.
-        """
-        check_type(headers, dict)
-        check_type(site_id, basestring,
-                   may_be_none=False)
-        if headers is not None:
-            if '__runsync' in headers:
-                check_type(headers.get('__runsync'),
-                           bool, may_be_none=False)
-            if '__runsynctimeout' in headers:
-                check_type(headers.get('__runsynctimeout'),
-                           int)
-            if '__persistbapioutput' in headers:
-                check_type(headers.get('__persistbapioutput'),
-                           bool, may_be_none=False)
-            if 'X-Auth-Token' in headers:
-                check_type(headers.get('X-Auth-Token'),
-                           basestring, may_be_none=False)
-
-        _params = {
-        }
-        _params.update(request_parameters)
-        _params = dict_from_items_with_values(_params)
-
-        path_params = {
-            'siteId': site_id,
-        }
-
-        with_custom_headers = False
-        _headers = self._session.headers or {}
-        if headers:
-            _headers.update(dict_of_str(headers))
-            with_custom_headers = True
-
-        e_url = ('/dna/intent/api/v1/site/${siteId}')
-        endpoint_full_url = apply_path_params(e_url, path_params)
-        if with_custom_headers:
-            json_data = self._session.delete(endpoint_full_url, params=_params,
-                                             headers=_headers)
-        else:
-            json_data = self._session.delete(endpoint_full_url, params=_params)
-
-        return self._object_factory('bpm_92acda91406aa050_v1_3_0', json_data)
+        return self._object_factory('bpm_6fb4ab3643faa80f_v2_1_1', json_data)
 
     def get_site_count(self,
                        site_id=None,
@@ -460,7 +376,7 @@ class Sites(object):
         """API to get site count .
 
         Args:
-            site_id(basestring): site id.
+            site_id(basestring): Site id to retrieve site count.
             headers(dict): Dictionary of HTTP Headers to send with the Request
                 .
             **request_parameters: Additional request parameters (provides
@@ -478,12 +394,6 @@ class Sites(object):
         check_type(headers, dict)
         check_type(site_id, basestring)
         if headers is not None:
-            if '__persistbapioutput' in headers:
-                check_type(headers.get('__persistbapioutput'),
-                           bool, may_be_none=False)
-            if '__runsynctimeout' in headers:
-                check_type(headers.get('__runsynctimeout'),
-                           int)
             if 'X-Auth-Token' in headers:
                 check_type(headers.get('X-Auth-Token'),
                            basestring, may_be_none=False)
@@ -512,20 +422,133 @@ class Sites(object):
         else:
             json_data = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_d9bdb9034df99dba_v1_3_0', json_data)
+        return self._object_factory('bpm_b0b7eabc4f4b9b28_v2_1_1', json_data)
 
-    def assign_device_to_site(self,
-                              site_id,
-                              device=None,
-                              headers=None,
-                              payload=None,
-                              active_validation=True,
-                              **request_parameters):
-        """Assigns list of devices to a site.
+    def delete_site(self,
+                    site_id,
+                    headers=None,
+                    **request_parameters):
+        """Delete site with area/building/floor by siteId.
 
         Args:
-            device(list): Device, property of the request body (list of objects).
-            site_id(basestring): Site id to which the device is assigned.
+            site_id(basestring): Site id to which site details to be deleted.
+            headers(dict): Dictionary of HTTP Headers to send with the Request
+                .
+            **request_parameters: Additional request parameters (provides
+                support for parameters that may be added in the future).
+
+        Returns:
+            MyDict: JSON response. Access the object's properties by using
+            the dot notation or the bracket notation.
+
+        Raises:
+            TypeError: If the parameter types are incorrect.
+            MalformedRequest: If the request body created is invalid.
+            ApiError: If the DNA Center cloud returns an error.
+        """
+        check_type(headers, dict)
+        check_type(site_id, basestring,
+                   may_be_none=False)
+        if headers is not None:
+            if 'X-Auth-Token' in headers:
+                check_type(headers.get('X-Auth-Token'),
+                           basestring, may_be_none=False)
+
+        _params = {
+        }
+        _params.update(request_parameters)
+        _params = dict_from_items_with_values(_params)
+
+        path_params = {
+            'siteId': site_id,
+        }
+
+        with_custom_headers = False
+        _headers = self._session.headers or {}
+        if headers:
+            _headers.update(dict_of_str(headers))
+            with_custom_headers = True
+
+        e_url = ('/dna/intent/api/v1/site/${siteId}')
+        endpoint_full_url = apply_path_params(e_url, path_params)
+        if with_custom_headers:
+            json_data = self._session.delete(endpoint_full_url, params=_params,
+                                             headers=_headers)
+        else:
+            json_data = self._session.delete(endpoint_full_url, params=_params)
+
+        return self._object_factory('bpm_f083cb13484a8fae_v2_1_1', json_data)
+
+    def get_membership(self,
+                       site_id,
+                       headers=None,
+                       **request_parameters):
+        """Getting the site children details and device details.
+
+        Args:
+            site_id(basestring): Site id to retrieve device associated with the site.
+            headers(dict): Dictionary of HTTP Headers to send with the Request
+                .
+            **request_parameters: Additional request parameters (provides
+                support for parameters that may be added in the future).
+
+        Returns:
+            MyDict: JSON response. Access the object's properties by using
+            the dot notation or the bracket notation.
+
+        Raises:
+            TypeError: If the parameter types are incorrect.
+            MalformedRequest: If the request body created is invalid.
+            ApiError: If the DNA Center cloud returns an error.
+        """
+        check_type(headers, dict)
+        check_type(site_id, basestring,
+                   may_be_none=False)
+        if headers is not None:
+            if 'X-Auth-Token' in headers:
+                check_type(headers.get('X-Auth-Token'),
+                           basestring, may_be_none=False)
+
+        _params = {
+        }
+        _params.update(request_parameters)
+        _params = dict_from_items_with_values(_params)
+
+        path_params = {
+            'siteId': site_id,
+        }
+
+        with_custom_headers = False
+        _headers = self._session.headers or {}
+        if headers:
+            _headers.update(dict_of_str(headers))
+            with_custom_headers = True
+
+        e_url = ('/dna/intent/api/v1/membership/${siteId}')
+        endpoint_full_url = apply_path_params(e_url, path_params)
+        if with_custom_headers:
+            json_data = self._session.get(endpoint_full_url, params=_params,
+                                          headers=_headers)
+        else:
+            json_data = self._session.get(endpoint_full_url, params=_params)
+
+        return self._object_factory('bpm_eba669054e08a60e_v2_1_1', json_data)
+
+    def update_site(self,
+                    site_id,
+                    site=None,
+                    type=None,
+                    headers=None,
+                    payload=None,
+                    active_validation=True,
+                    **request_parameters):
+        """Update site area/building/floor with specified hierarchy and new
+        values.
+
+        Args:
+            site(object): Site, property of the request body.
+            type(string): Type, property of the request body. Available values are 'area', 'building' and 'floor'.
+            site_id(basestring): Site id to which site details to be updated.
             headers(dict): Dictionary of HTTP Headers to send with the Request
                 .
             payload(dict): A JSON serializable Python object to send in the
@@ -551,13 +574,13 @@ class Sites(object):
         if headers is not None:
             if '__runsync' in headers:
                 check_type(headers.get('__runsync'),
-                           bool, may_be_none=False)
+                           bool)
+            if '__timeout' in headers:
+                check_type(headers.get('__timeout'),
+                           int)
             if '__persistbapioutput' in headers:
                 check_type(headers.get('__persistbapioutput'),
                            bool, may_be_none=False)
-            if '__runsynctimeout' in headers:
-                check_type(headers.get('__runsynctimeout'),
-                           int)
             if 'X-Auth-Token' in headers:
                 check_type(headers.get('X-Auth-Token'),
                            basestring, may_be_none=False)
@@ -572,13 +595,15 @@ class Sites(object):
         }
 
         _payload = {
-            'device':
-                device,
+            'type':
+                type,
+            'site':
+                site,
         }
         _payload.update(payload or {})
         _payload = dict_from_items_with_values(_payload)
         if active_validation:
-            self._request_validator('jsd_eeb168eb41988e07_v1_3_0')\
+            self._request_validator('jsd_eeb7eb4b4bd8a1dd_v2_1_1')\
                 .validate(_payload)
 
         with_custom_headers = False
@@ -587,76 +612,14 @@ class Sites(object):
             _headers.update(dict_of_str(headers))
             with_custom_headers = True
 
-        e_url = ('/dna/system/api/v1/site/${siteId}/device')
+        e_url = ('/dna/intent/api/v1/site/${siteId}')
         endpoint_full_url = apply_path_params(e_url, path_params)
         if with_custom_headers:
-            json_data = self._session.post(endpoint_full_url, params=_params,
-                                           json=_payload,
-                                           headers=_headers)
-        else:
-            json_data = self._session.post(endpoint_full_url, params=_params,
-                                           json=_payload)
-
-        return self._object_factory('bpm_eeb168eb41988e07_v1_3_0', json_data)
-
-    def get_membership(self,
-                       site_id,
-                       headers=None,
-                       **request_parameters):
-        """Getting the site children details and device details.
-
-        Args:
-            site_id(basestring): site id.
-            headers(dict): Dictionary of HTTP Headers to send with the Request
-                .
-            **request_parameters: Additional request parameters (provides
-                support for parameters that may be added in the future).
-
-        Returns:
-            MyDict: JSON response. Access the object's properties by using
-            the dot notation or the bracket notation.
-
-        Raises:
-            TypeError: If the parameter types are incorrect.
-            MalformedRequest: If the request body created is invalid.
-            ApiError: If the DNA Center cloud returns an error.
-        """
-        check_type(headers, dict)
-        check_type(site_id, basestring,
-                   may_be_none=False)
-        if headers is not None:
-            if '__runsync' in headers:
-                check_type(headers.get('__runsync'),
-                           bool)
-            if '__runsynctimeout' in headers:
-                check_type(headers.get('__runsynctimeout'),
-                           int)
-            if 'X-Auth-Token' in headers:
-                check_type(headers.get('X-Auth-Token'),
-                           basestring, may_be_none=False)
-
-        _params = {
-            'siteId':
-                site_id,
-        }
-        _params.update(request_parameters)
-        _params = dict_from_items_with_values(_params)
-
-        path_params = {
-        }
-
-        with_custom_headers = False
-        _headers = self._session.headers or {}
-        if headers:
-            _headers.update(dict_of_str(headers))
-            with_custom_headers = True
-
-        e_url = ('/dna/intent/api/v1/membership')
-        endpoint_full_url = apply_path_params(e_url, path_params)
-        if with_custom_headers:
-            json_data = self._session.get(endpoint_full_url, params=_params,
+            json_data = self._session.put(endpoint_full_url, params=_params,
+                                          json=_payload,
                                           headers=_headers)
         else:
-            json_data = self._session.get(endpoint_full_url, params=_params)
+            json_data = self._session.put(endpoint_full_url, params=_params,
+                                          json=_payload)
 
-        return self._object_factory('bpm_eba669054e08a60e_v1_3_0', json_data)
+        return self._object_factory('bpm_eeb7eb4b4bd8a1dd_v2_1_1', json_data)
