@@ -22,13 +22,7 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 
-
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-    unicode_literals,
-)
+from __future__ import absolute_import, division, print_function, unicode_literals
 
 from builtins import *
 
@@ -36,15 +30,15 @@ from past.builtins import basestring
 
 from ...restsession import RestSession
 from ...utils import (
+    apply_path_params,
     check_type,
     dict_from_items_with_values,
-    apply_path_params,
     dict_of_str,
 )
 
 
 class Clients(object):
-    """Cisco DNA Center Clients API (version: 1.3.3).
+    """Cisco DNA Center Clients API (version: 2.1.2).
 
     Wraps the DNA Center Clients
     API and exposes the API as native Python
@@ -130,13 +124,13 @@ class Clients(object):
         else:
             json_data = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_149aa93b4ddb80dd_v1_3_3', json_data)
+        return self._object_factory('bpm_149aa93b4ddb80dd_v2_1_2', json_data)
 
     def get_client_enrichment_details(self,
                                       headers=None,
                                       **request_parameters):
         """Enriches a given network End User context (a network user-id or
-        end user’s device Mac Address) with details about the
+        end user's device Mac Address) with details about the
         user, the devices that the user is connected to and the
         assurance issues that the user is impacted by.
 
@@ -193,7 +187,7 @@ class Clients(object):
         else:
             json_data = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_b199685d4d089a67_v1_3_3', json_data)
+        return self._object_factory('bpm_b199685d4d089a67_v2_1_2', json_data)
 
     def get_client_detail(self,
                           mac_address,
@@ -259,4 +253,4 @@ class Clients(object):
         else:
             json_data = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_e2adba7943bab3e9_v1_3_3', json_data)
+        return self._object_factory('bpm_e2adba7943bab3e9_v2_1_2', json_data)
