@@ -22,13 +22,7 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 
-
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-    unicode_literals,
-)
+from __future__ import absolute_import, division, print_function, unicode_literals
 
 from builtins import *
 
@@ -36,15 +30,15 @@ from past.builtins import basestring
 
 from ...restsession import RestSession
 from ...utils import (
+    apply_path_params,
     check_type,
     dict_from_items_with_values,
-    apply_path_params,
     dict_of_str,
 )
 
 
 class Itsm(object):
-    """Cisco DNA Center ITSM API (version: 2.2.3.3).
+    """Cisco DNA Center ITSM API (version: 2.1.2).
 
     Wraps the DNA Center ITSM
     API and exposes the API as native Python
@@ -72,80 +66,15 @@ class Itsm(object):
         self._object_factory = object_factory
         self._request_validator = request_validator
 
-    def get_cmdb_sync_status(self,
-                             date=None,
-                             status=None,
-                             headers=None,
-                             **request_parameters):
-        """This API allows to retrieve the detail of CMDB sync status.It accepts two query parameter "status","date".The
-        supported values for status field are "Success","Failed","Unknown" and date field should be in "YYYY-MM-
-        DD" format. By default all the cmdb sync status will be send as response and based on the query
-        parameter filtered detail will be send as response. .
-
-        Args:
-            status(basestring): status query parameter. Supported values are "Success","Failed" and "Unknown".
-                Providing other values will result in all the available sync job status. .
-            date(basestring): date query parameter. Provide date in "YYYY-MM-DD" format .
-            headers(dict): Dictionary of HTTP Headers to send with the Request
-                .
-            **request_parameters: Additional request parameters (provides
-                support for parameters that may be added in the future).
-
-        Returns:
-            list: JSON response. A list of MyDict objects.
-            Access the object's properties by using the dot notation
-            or the bracket notation.
-
-        Raises:
-            TypeError: If the parameter types are incorrect.
-            MalformedRequest: If the request body created is invalid.
-            ApiError: If the DNA Center cloud returns an error.
-        """
-        check_type(headers, dict)
-        check_type(status, basestring)
-        check_type(date, basestring)
-        if headers is not None:
-            if 'X-Auth-Token' in headers:
-                check_type(headers.get('X-Auth-Token'),
-                           basestring, may_be_none=False)
-
-        _params = {
-            'status':
-                status,
-            'date':
-                date,
-        }
-        _params.update(request_parameters)
-        _params = dict_from_items_with_values(_params)
-
-        path_params = {
-        }
-
-        with_custom_headers = False
-        _headers = self._session.headers or {}
-        if headers:
-            _headers.update(dict_of_str(headers))
-            with_custom_headers = True
-
-        e_url = ('/dna/intent/api/v1/cmdb-sync/detail')
-        endpoint_full_url = apply_path_params(e_url, path_params)
-        if with_custom_headers:
-            json_data = self._session.get(endpoint_full_url, params=_params,
-                                          headers=_headers)
-        else:
-            json_data = self._session.get(endpoint_full_url, params=_params)
-
-        return self._object_factory('bpm_eb1bf346225a4ba24f18408ffca7c9_v2_2_3_3', json_data)
-
     def get_failed_itsm_events(self,
                                instance_id=None,
                                headers=None,
                                **request_parameters):
-        """Used to retrieve the list of integration events that failed to create tickets in ITSM .
+        """Used to retrieve the list of integration events that failed to
+        create tickets in ITSM.
 
         Args:
-            instance_id(basestring): instanceId query parameter. Instance Id of the failed event as in the Runtime
-                Dashboard .
+            instance_id(basestring): Instance Id of the failed event as in the Runtime Dashboard.
             headers(dict): Dictionary of HTTP Headers to send with the Request
                 .
             **request_parameters: Additional request parameters (provides
@@ -192,17 +121,19 @@ class Itsm(object):
         else:
             json_data = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_da70082b298a5a908edb780a61bd4ca6_v2_2_3_3', json_data)
+        return self._object_factory('bpm_a293b82a42a8ab15_v2_1_2', json_data)
 
     def retry_integration_events(self,
                                  headers=None,
                                  payload=None,
                                  active_validation=True,
                                  **request_parameters):
-        """Allows retry of multiple failed ITSM event instances. The retry request payload can be given as a list of
-        strings: ["instance1","instance2","instance3",..] A minimum of one instance Id is mandatory. The list of
-        failed event instance Ids can be retrieved using the 'Get Failed ITSM Events' API in the 'instanceId'
-        attribute. .
+        """Allows retry of multiple failed ITSM event instances. The retry
+        request payload can be given as a list of strings:
+        ["instance1","instance2","instance3",..] A minimum of
+        one instance Id is mandatory. The list of failed event
+        instance Ids can be retrieved using the 'Get Failed ITSM
+        Events' API in the 'instanceId' attribute.
 
         Args:
             headers(dict): Dictionary of HTTP Headers to send with the Request
@@ -237,9 +168,10 @@ class Itsm(object):
 
         path_params = {
         }
+
         _payload = payload or []
         if active_validation:
-            self._request_validator('jsd_cfb1d6e52878d057740de275896_v2_2_3_3')\
+            self._request_validator('jsd_fa9a98174129af50_v2_1_2')\
                 .validate(_payload)
 
         with_custom_headers = False
@@ -258,4 +190,4 @@ class Itsm(object):
             json_data = self._session.post(endpoint_full_url, params=_params,
                                            json=_payload)
 
-        return self._object_factory('bpm_cfb1d6e52878d057740de275896_v2_2_3_3', json_data)
+        return self._object_factory('bpm_fa9a98174129af50_v2_1_2', json_data)
