@@ -22,13 +22,7 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 
-
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-    unicode_literals,
-)
+from __future__ import absolute_import, division, print_function, unicode_literals
 
 from builtins import *
 
@@ -36,15 +30,15 @@ from past.builtins import basestring
 
 from ...restsession import RestSession
 from ...utils import (
+    apply_path_params,
     check_type,
     dict_from_items_with_values,
-    apply_path_params,
     dict_of_str,
 )
 
 
 class ConfigurationArchive(object):
-    """Cisco DNA Center Configuration Archive API (version: 2.1.2).
+    """Cisco DNA Center Configuration Archive API (version: 2.2.1).
 
     Wraps the DNA Center Configuration Archive
     API and exposes the API as native Python
@@ -73,13 +67,23 @@ class ConfigurationArchive(object):
         self._request_validator = request_validator
 
     def export_device_configurations(self,
+                                     deviceId=None,
+                                     password=None,
                                      headers=None,
+                                     payload=None,
+                                     active_validation=True,
                                      **request_parameters):
         """Export Device configurations to an encrypted zip file.
 
         Args:
+            deviceId(list): Configuration Archive's deviceId (list of strings).
+            password(string): Configuration Archive's password.
             headers(dict): Dictionary of HTTP Headers to send with the Request
                 .
+            payload(dict): A JSON serializable Python object to send in the
+                body of the Request.
+            active_validation(bool): Enable/Disable payload validation.
+                Defaults to True.
             **request_parameters: Additional request parameters (provides
                 support for parameters that may be added in the future).
 
@@ -93,6 +97,7 @@ class ConfigurationArchive(object):
             ApiError: If the DNA Center cloud returns an error.
         """
         check_type(headers, dict)
+        check_type(payload, dict)
         if headers is not None:
             if 'Content-Type' in headers:
                 check_type(headers.get('Content-Type'),
@@ -108,6 +113,17 @@ class ConfigurationArchive(object):
 
         path_params = {
         }
+        _payload = {
+            'deviceId':
+                deviceId,
+            'password':
+                password,
+        }
+        _payload.update(payload or {})
+        _payload = dict_from_items_with_values(_payload)
+        if active_validation:
+            self._request_validator('jsd_e85b40c5ca055f4c82281617a8f95644_v2_2_1')\
+                .validate(_payload)
 
         with_custom_headers = False
         _headers = self._session.headers or {}
@@ -119,8 +135,10 @@ class ConfigurationArchive(object):
         endpoint_full_url = apply_path_params(e_url, path_params)
         if with_custom_headers:
             json_data = self._session.post(endpoint_full_url, params=_params,
+                                           json=_payload,
                                            headers=_headers)
         else:
-            json_data = self._session.post(endpoint_full_url, params=_params)
+            json_data = self._session.post(endpoint_full_url, params=_params,
+                                           json=_payload)
 
-        return self._object_factory('bpm_51a40aba4c68ac17_v2_1_2', json_data)
+        return self._object_factory('bpm_e85b40c5ca055f4c82281617a8f95644_v2_2_1', json_data)
