@@ -22,13 +22,7 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 
-
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-    unicode_literals,
-)
+from __future__ import absolute_import, division, print_function, unicode_literals
 
 from builtins import *
 
@@ -36,15 +30,15 @@ from past.builtins import basestring
 
 from ...restsession import RestSession
 from ...utils import (
+    apply_path_params,
     check_type,
     dict_from_items_with_values,
-    apply_path_params,
     dict_of_str,
 )
 
 
 class Issues(object):
-    """Cisco DNA Center Issues API (version: 2.2.2.3).
+    """Cisco DNA Center Issues API (version: 2.2.1).
 
     Wraps the DNA Center Issues
     API and exposes the API as native Python
@@ -72,63 +66,6 @@ class Issues(object):
         self._object_factory = object_factory
         self._request_validator = request_validator
 
-    def get_issue_enrichment_details(self,
-                                     headers=None,
-                                     **request_parameters):
-        """Enriches a given network issue context (an issue id or end user’s Mac Address) with details about the issue(s),
-        impacted hosts and suggested actions for remediation .
-
-        Args:
-            headers(dict): Dictionary of HTTP Headers to send with the Request
-                .
-            **request_parameters: Additional request parameters (provides
-                support for parameters that may be added in the future).
-
-        Returns:
-            MyDict: JSON response. Access the object's properties by using
-            the dot notation or the bracket notation.
-
-        Raises:
-            TypeError: If the parameter types are incorrect.
-            MalformedRequest: If the request body created is invalid.
-            ApiError: If the DNA Center cloud returns an error.
-        """
-        check_type(headers, dict)
-        if headers is not None:
-            if 'entity_type' in headers:
-                check_type(headers.get('entity_type'),
-                           basestring, may_be_none=False)
-            if 'entity_value' in headers:
-                check_type(headers.get('entity_value'),
-                           basestring, may_be_none=False)
-            if 'X-Auth-Token' in headers:
-                check_type(headers.get('X-Auth-Token'),
-                           basestring, may_be_none=False)
-
-        _params = {
-        }
-        _params.update(request_parameters)
-        _params = dict_from_items_with_values(_params)
-
-        path_params = {
-        }
-
-        with_custom_headers = False
-        _headers = self._session.headers or {}
-        if headers:
-            _headers.update(dict_of_str(headers))
-            with_custom_headers = True
-
-        e_url = ('/dna/intent/api/v1/issue-enrichment-details')
-        endpoint_full_url = apply_path_params(e_url, path_params)
-        if with_custom_headers:
-            json_data = self._session.get(endpoint_full_url, params=_params,
-                                          headers=_headers)
-        else:
-            json_data = self._session.get(endpoint_full_url, params=_params)
-
-        return self._object_factory('bpm_f2f039811951c0af53e3381ae91225_v2_2_2_3', json_data)
-
     def issues(self,
                ai_driven=None,
                device_id=None,
@@ -141,22 +78,22 @@ class Issues(object):
                headers=None,
                **request_parameters):
         """Intent API to get a list of global issues, issues for a specific device, or issue for a specific client device's
-        MAC address. .
+        MAC address.
 
         Args:
-            start_time(int): startTime query parameter. Starting epoch time in milliseconds of query time window .
-            end_time(int): endTime query parameter. Ending epoch time in milliseconds of query time window .
-            site_id(basestring): siteId query parameter. Assurance UUID value of the site in the issue content .
-            device_id(basestring): deviceId query parameter. Assurance UUID value of the device in the issue content
-                .
+            start_time(int): startTime query parameter. Starting epoch time in milliseconds of query time window.
+            end_time(int): endTime query parameter. Ending epoch time in milliseconds of query time window.
+            site_id(basestring): siteId query parameter. Assurance UUID value of the site in the issue content.
+            device_id(basestring): deviceId query parameter. Assurance UUID value of the device in the issue
+                content.
             mac_address(basestring): macAddress query parameter. Client's device MAC address of the issue (format
-                xx:xx:xx:xx:xx:xx) .
+                xx:xx:xx:xx:xx:xx).
             priority(basestring): priority query parameter. The issue's priority value (One of P1, P2, P3, or
-                P4)(Use only when macAddress and deviceId are not provided) .
+                P4)(Use only when macAddress and deviceId are not provided).
             ai_driven(basestring): aiDriven query parameter. The issue's AI driven value (Yes or No)(Use only when
-                macAddress and deviceId are not provided) .
+                macAddress and deviceId are not provided).
             issue_status(basestring): issueStatus query parameter. The issue's status value (One of ACTIVE, IGNORED,
-                RESOLVED) .
+                RESOLVED) (Use only when macAddress and deviceId are not provided).
             headers(dict): Dictionary of HTTP Headers to send with the Request
                 .
             **request_parameters: Additional request parameters (provides
@@ -223,4 +160,61 @@ class Issues(object):
         else:
             json_data = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_aaef3b519ba8b9fb2cbf43b985_v2_2_2_3', json_data)
+        return self._object_factory('bpm_aaef3b519ba8b9fb2cbf43b985_v2_2_1', json_data)
+
+    def get_issue_enrichment_details(self,
+                                     headers=None,
+                                     **request_parameters):
+        """Enriches a given network issue context (an issue id or end user’s Mac Address) with details about the issue(s),
+        impacted hosts and suggested actions for remediation.
+
+        Args:
+            headers(dict): Dictionary of HTTP Headers to send with the Request
+                .
+            **request_parameters: Additional request parameters (provides
+                support for parameters that may be added in the future).
+
+        Returns:
+            MyDict: JSON response. Access the object's properties by using
+            the dot notation or the bracket notation.
+
+        Raises:
+            TypeError: If the parameter types are incorrect.
+            MalformedRequest: If the request body created is invalid.
+            ApiError: If the DNA Center cloud returns an error.
+        """
+        check_type(headers, dict)
+        if headers is not None:
+            if 'entity_type' in headers:
+                check_type(headers.get('entity_type'),
+                           basestring, may_be_none=False)
+            if 'entity_value' in headers:
+                check_type(headers.get('entity_value'),
+                           basestring, may_be_none=False)
+            if 'X-Auth-Token' in headers:
+                check_type(headers.get('X-Auth-Token'),
+                           basestring, may_be_none=False)
+
+        _params = {
+        }
+        _params.update(request_parameters)
+        _params = dict_from_items_with_values(_params)
+
+        path_params = {
+        }
+
+        with_custom_headers = False
+        _headers = self._session.headers or {}
+        if headers:
+            _headers.update(dict_of_str(headers))
+            with_custom_headers = True
+
+        e_url = ('/dna/intent/api/v1/issue-enrichment-details')
+        endpoint_full_url = apply_path_params(e_url, path_params)
+        if with_custom_headers:
+            json_data = self._session.get(endpoint_full_url, params=_params,
+                                          headers=_headers)
+        else:
+            json_data = self._session.get(endpoint_full_url, params=_params)
+
+        return self._object_factory('bpm_f2f039811951c0af53e3381ae91225_v2_2_1', json_data)
