@@ -22,13 +22,7 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 
-
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-    unicode_literals,
-)
+from __future__ import absolute_import, division, print_function, unicode_literals
 
 from builtins import *
 
@@ -36,15 +30,15 @@ from past.builtins import basestring
 
 from ...restsession import RestSession
 from ...utils import (
+    apply_path_params,
     check_type,
     dict_from_items_with_values,
-    apply_path_params,
     dict_of_str,
 )
 
 
 class Task(object):
-    """Cisco DNA Center Task API (version: 2.1.1).
+    """Cisco DNA Center Task API (version: 2.2.1).
 
     Wraps the DNA Center Task
     API and exposes the API as native Python
@@ -88,16 +82,20 @@ class Task(object):
         """Returns Task count.
 
         Args:
-            start_time(basestring): This is the epoch start time from which tasks need to be fetched.
-            end_time(basestring): This is the epoch end time upto which audit records need to be fetched.
-            data(basestring): Fetch tasks that contains this data.
-            error_code(basestring): Fetch tasks that have this error code.
-            service_type(basestring): Fetch tasks with this service type.
-            username(basestring): Fetch tasks with this username.
-            progress(basestring): Fetch tasks that contains this progress.
-            is_error(basestring): Fetch tasks ended as success or failure. Valid values: true, false.
-            failure_reason(basestring): Fetch tasks that contains this failure reason.
-            parent_id(basestring): Fetch tasks that have this parent Id.
+            start_time(basestring): startTime query parameter. This is the epoch start time from which tasks need to
+                be fetched.
+            end_time(basestring): endTime query parameter. This is the epoch end time upto which audit records need
+                to be fetched.
+            data(basestring): data query parameter. Fetch tasks that contains this data.
+            error_code(basestring): errorCode query parameter. Fetch tasks that have this error code.
+            service_type(basestring): serviceType query parameter. Fetch tasks with this service type.
+            username(basestring): username query parameter. Fetch tasks with this username.
+            progress(basestring): progress query parameter. Fetch tasks that contains this progress.
+            is_error(basestring): isError query parameter. Fetch tasks ended as success or failure. Valid values:
+                true, false.
+            failure_reason(basestring): failureReason query parameter. Fetch tasks that contains this failure
+                reason.
+            parent_id(basestring): parentId query parameter. Fetch tasks that have this parent Id.
             headers(dict): Dictionary of HTTP Headers to send with the Request
                 .
             **request_parameters: Additional request parameters (provides
@@ -170,7 +168,7 @@ class Task(object):
         else:
             json_data = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_26b44ab04649a183_v2_1_1', json_data)
+        return self._object_factory('bpm_d0586946be75e0f9f2c170217d45a28_v2_2_1', json_data)
 
     def get_task_by_id(self,
                        task_id,
@@ -179,7 +177,7 @@ class Task(object):
         """Returns a task by specified id.
 
         Args:
-            task_id(basestring): UUID of the Task.
+            task_id(basestring): taskId path parameter. UUID of the Task.
             headers(dict): Dictionary of HTTP Headers to send with the Request
                 .
             **request_parameters: Additional request parameters (provides
@@ -217,7 +215,7 @@ class Task(object):
             _headers.update(dict_of_str(headers))
             with_custom_headers = True
 
-        e_url = ('/dna/intent/api/v1/task/${taskId}')
+        e_url = ('/dna/intent/api/v1/task/{taskId}')
         endpoint_full_url = apply_path_params(e_url, path_params)
         if with_custom_headers:
             json_data = self._session.get(endpoint_full_url, params=_params,
@@ -225,7 +223,74 @@ class Task(object):
         else:
             json_data = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_a1a9387346ba92b1_v2_1_1', json_data)
+        return self._object_factory('bpm_99a75ba5a6bae1d568700bd3_v2_2_1', json_data)
+
+    def get_task_by_operationid(self,
+                                limit,
+                                offset,
+                                operation_id,
+                                headers=None,
+                                **request_parameters):
+        """Returns root tasks associated with an Operationid.
+
+        Args:
+            operation_id(basestring): operationId path parameter.
+            offset(int): offset path parameter. Index, minimum value is 0.
+            limit(int): limit path parameter. The maximum value of {limit} supported is 500.               Base 1
+                indexing for {limit}, minimum value is 1.
+            headers(dict): Dictionary of HTTP Headers to send with the Request
+                .
+            **request_parameters: Additional request parameters (provides
+                support for parameters that may be added in the future).
+
+        Returns:
+            MyDict: JSON response. Access the object's properties by using
+            the dot notation or the bracket notation.
+
+        Raises:
+            TypeError: If the parameter types are incorrect.
+            MalformedRequest: If the request body created is invalid.
+            ApiError: If the DNA Center cloud returns an error.
+        """
+        check_type(headers, dict)
+        check_type(operation_id, basestring,
+                   may_be_none=False)
+        check_type(offset, int,
+                   may_be_none=False)
+        check_type(limit, int,
+                   may_be_none=False)
+        if headers is not None:
+            if 'X-Auth-Token' in headers:
+                check_type(headers.get('X-Auth-Token'),
+                           basestring, may_be_none=False)
+
+        _params = {
+        }
+        _params.update(request_parameters)
+        _params = dict_from_items_with_values(_params)
+
+        path_params = {
+            'operationId': operation_id,
+            'offset': offset,
+            'limit': limit,
+        }
+
+        with_custom_headers = False
+        _headers = self._session.headers or {}
+        if headers:
+            _headers.update(dict_of_str(headers))
+            with_custom_headers = True
+
+        e_url = ('/dna/intent/api/v1/task/operation/{operationId}/{offset}'
+                 + '/{limit}')
+        endpoint_full_url = apply_path_params(e_url, path_params)
+        if with_custom_headers:
+            json_data = self._session.get(endpoint_full_url, params=_params,
+                                          headers=_headers)
+        else:
+            json_data = self._session.get(endpoint_full_url, params=_params)
+
+        return self._object_factory('bpm_d95c21e41dce5a9dbee07d33eefef2b2_v2_2_1', json_data)
 
     def get_tasks(self,
                   data=None,
@@ -247,20 +312,24 @@ class Task(object):
         """Returns task(s) based on filter criteria.
 
         Args:
-            start_time(basestring): This is the epoch start time from which tasks need to be fetched.
-            end_time(basestring): This is the epoch end time upto which audit records need to be fetched.
-            data(basestring): Fetch tasks that contains this data.
-            error_code(basestring): Fetch tasks that have this error code.
-            service_type(basestring): Fetch tasks with this service type.
-            username(basestring): Fetch tasks with this username.
-            progress(basestring): Fetch tasks that contains this progress.
-            is_error(basestring): Fetch tasks ended as success or failure. Valid values: true, false.
-            failure_reason(basestring): Fetch tasks that contains this failure reason.
-            parent_id(basestring): Fetch tasks that have this parent Id.
+            start_time(basestring): startTime query parameter. This is the epoch start time from which tasks need to
+                be fetched.
+            end_time(basestring): endTime query parameter. This is the epoch end time upto which audit records need
+                to be fetched.
+            data(basestring): data query parameter. Fetch tasks that contains this data.
+            error_code(basestring): errorCode query parameter. Fetch tasks that have this error code.
+            service_type(basestring): serviceType query parameter. Fetch tasks with this service type.
+            username(basestring): username query parameter. Fetch tasks with this username.
+            progress(basestring): progress query parameter. Fetch tasks that contains this progress.
+            is_error(basestring): isError query parameter. Fetch tasks ended as success or failure. Valid values:
+                true, false.
+            failure_reason(basestring): failureReason query parameter. Fetch tasks that contains this failure
+                reason.
+            parent_id(basestring): parentId query parameter. Fetch tasks that have this parent Id.
             offset(basestring): offset query parameter.
             limit(basestring): limit query parameter.
-            sort_by(basestring): Sort results by this field.
-            order(basestring): Sort order asc or dsc.
+            sort_by(basestring): sortBy query parameter. Sort results by this field.
+            order(basestring): order query parameter. Sort order asc or dsc.
             headers(dict): Dictionary of HTTP Headers to send with the Request
                 .
             **request_parameters: Additional request parameters (provides
@@ -345,7 +414,7 @@ class Task(object):
         else:
             json_data = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_e78bb8a2449b9eed_v2_1_1', json_data)
+        return self._object_factory('bpm_ff485556f6504d8443789f42098be7_v2_2_1', json_data)
 
     def get_task_tree(self,
                       task_id,
@@ -354,7 +423,7 @@ class Task(object):
         """Returns a task with its children tasks by based on their id.
 
         Args:
-            task_id(basestring): UUID of the Task.
+            task_id(basestring): taskId path parameter. UUID of the Task.
             headers(dict): Dictionary of HTTP Headers to send with the Request
                 .
             **request_parameters: Additional request parameters (provides
@@ -392,7 +461,7 @@ class Task(object):
             _headers.update(dict_of_str(headers))
             with_custom_headers = True
 
-        e_url = ('/dna/intent/api/v1/task/${taskId}/tree')
+        e_url = ('/dna/intent/api/v1/task/{taskId}/tree')
         endpoint_full_url = apply_path_params(e_url, path_params)
         if with_custom_headers:
             json_data = self._session.get(endpoint_full_url, params=_params,
@@ -400,71 +469,4 @@ class Task(object):
         else:
             json_data = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_f5a269c44f2a95fa_v2_1_1', json_data)
-
-    def get_task_by_operationid(self,
-                                limit,
-                                offset,
-                                operation_id,
-                                headers=None,
-                                **request_parameters):
-        """Returns root tasks associated with an Operationid.
-
-        Args:
-            operation_id(basestring): operationId path parameter.
-            offset(int): Index, minimum value is 0.
-            limit(int): The maximum value of {limit} supported is 500.               Base 1 indexing for {limit},
-                minimum value is 1.
-            headers(dict): Dictionary of HTTP Headers to send with the Request
-                .
-            **request_parameters: Additional request parameters (provides
-                support for parameters that may be added in the future).
-
-        Returns:
-            MyDict: JSON response. Access the object's properties by using
-            the dot notation or the bracket notation.
-
-        Raises:
-            TypeError: If the parameter types are incorrect.
-            MalformedRequest: If the request body created is invalid.
-            ApiError: If the DNA Center cloud returns an error.
-        """
-        check_type(headers, dict)
-        check_type(operation_id, basestring,
-                   may_be_none=False)
-        check_type(offset, int,
-                   may_be_none=False)
-        check_type(limit, int,
-                   may_be_none=False)
-        if headers is not None:
-            if 'X-Auth-Token' in headers:
-                check_type(headers.get('X-Auth-Token'),
-                           basestring, may_be_none=False)
-
-        _params = {
-        }
-        _params.update(request_parameters)
-        _params = dict_from_items_with_values(_params)
-
-        path_params = {
-            'operationId': operation_id,
-            'offset': offset,
-            'limit': limit,
-        }
-
-        with_custom_headers = False
-        _headers = self._session.headers or {}
-        if headers:
-            _headers.update(dict_of_str(headers))
-            with_custom_headers = True
-
-        e_url = ('/dna/intent/api/v1/task/operation/${operationId}/${offse'
-                 + 't}/${limit}')
-        endpoint_full_url = apply_path_params(e_url, path_params)
-        if with_custom_headers:
-            json_data = self._session.get(endpoint_full_url, params=_params,
-                                          headers=_headers)
-        else:
-            json_data = self._session.get(endpoint_full_url, params=_params)
-
-        return self._object_factory('bpm_e487f8d3481b94f2_v2_1_1', json_data)
+        return self._object_factory('bpm_fa2865e229b536aacd59585a1d29704_v2_2_1', json_data)
