@@ -22,13 +22,7 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 
-
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-    unicode_literals,
-)
+from __future__ import absolute_import, division, print_function, unicode_literals
 
 from builtins import *
 
@@ -36,15 +30,15 @@ from past.builtins import basestring
 
 from ...restsession import RestSession
 from ...utils import (
+    apply_path_params,
     check_type,
     dict_from_items_with_values,
-    apply_path_params,
     dict_of_str,
 )
 
 
 class Licenses(object):
-    """Cisco DNA Center Licenses API (version: 2.2.3.3).
+    """Cisco DNA Center Licenses API (version: 2.2.2.3).
 
     Wraps the DNA Center Licenses
     API and exposes the API as native Python
@@ -146,7 +140,7 @@ class Licenses(object):
         else:
             json_data = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_c0cf04bdc758b29bb11abbdacbd921_v2_2_3_3', json_data)
+        return self._object_factory('bpm_c0cf04bdc758b29bb11abbdacbd921_v2_2_2_3', json_data)
 
     def device_license_summary(self,
                                limit,
@@ -250,7 +244,7 @@ class Licenses(object):
         else:
             json_data = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_f4ba64eef4085d518a612835e128fe3c_v2_2_3_3', json_data)
+        return self._object_factory('bpm_f4ba64eef4085d518a612835e128fe3c_v2_2_2_3', json_data)
 
     def device_license_details(self,
                                device_uuid,
@@ -305,7 +299,7 @@ class Licenses(object):
         else:
             json_data = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_f04f865c01d5c17a5f0cb5abe620dd8_v2_2_3_3', json_data)
+        return self._object_factory('bpm_f04f865c01d5c17a5f0cb5abe620dd8_v2_2_2_3', json_data)
 
     def device_deregistration(self,
                               device_uuids=None,
@@ -359,7 +353,7 @@ class Licenses(object):
         _payload.update(payload or {})
         _payload = dict_from_items_with_values(_payload)
         if active_validation:
-            self._request_validator('jsd_b2f15d0c54c2862a60a904289ddd_v2_2_3_3')\
+            self._request_validator('jsd_b2f15d0c54c2862a60a904289ddd_v2_2_2_3')\
                 .validate(_payload)
 
         with_custom_headers = False
@@ -379,7 +373,7 @@ class Licenses(object):
             json_data = self._session.put(endpoint_full_url, params=_params,
                                           json=_payload)
 
-        return self._object_factory('bpm_b2f15d0c54c2862a60a904289ddd_v2_2_3_3', json_data)
+        return self._object_factory('bpm_b2f15d0c54c2862a60a904289ddd_v2_2_2_3', json_data)
 
     def device_registration(self,
                             virtual_account_name,
@@ -438,7 +432,7 @@ class Licenses(object):
         _payload.update(payload or {})
         _payload = dict_from_items_with_values(_payload)
         if active_validation:
-            self._request_validator('jsd_df26f516755a50b5b5477324cf5cb649_v2_2_3_3')\
+            self._request_validator('jsd_df26f516755a50b5b5477324cf5cb649_v2_2_2_3')\
                 .validate(_payload)
 
         with_custom_headers = False
@@ -458,7 +452,7 @@ class Licenses(object):
             json_data = self._session.put(endpoint_full_url, params=_params,
                                           json=_payload)
 
-        return self._object_factory('bpm_df26f516755a50b5b5477324cf5cb649_v2_2_3_3', json_data)
+        return self._object_factory('bpm_df26f516755a50b5b5477324cf5cb649_v2_2_2_3', json_data)
 
     def change_virtual_account(self,
                                smart_account_id,
@@ -522,7 +516,7 @@ class Licenses(object):
         _payload.update(payload or {})
         _payload = dict_from_items_with_values(_payload)
         if active_validation:
-            self._request_validator('jsd_bd5b507f58a50aab614e3d7409eec4c_v2_2_3_3')\
+            self._request_validator('jsd_bd5b507f58a50aab614e3d7409eec4c_v2_2_2_3')\
                 .validate(_payload)
 
         with_custom_headers = False
@@ -543,7 +537,7 @@ class Licenses(object):
             json_data = self._session.post(endpoint_full_url, params=_params,
                                            json=_payload)
 
-        return self._object_factory('bpm_bd5b507f58a50aab614e3d7409eec4c_v2_2_3_3', json_data)
+        return self._object_factory('bpm_bd5b507f58a50aab614e3d7409eec4c_v2_2_2_3', json_data)
 
     def virtual_account_details(self,
                                 smart_account_id,
@@ -599,7 +593,7 @@ class Licenses(object):
         else:
             json_data = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_ab450b197375fa9bcd95219113a3075_v2_2_3_3', json_data)
+        return self._object_factory('bpm_ab450b197375fa9bcd95219113a3075_v2_2_2_3', json_data)
 
     def smart_account_details(self,
                               headers=None,
@@ -649,7 +643,7 @@ class Licenses(object):
         else:
             json_data = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_ea3fdbde23325051a76b9d062c2962a0_v2_2_3_3', json_data)
+        return self._object_factory('bpm_ea3fdbde23325051a76b9d062c2962a0_v2_2_2_3', json_data)
 
     def license_term_details(self,
                              device_type,
@@ -718,7 +712,7 @@ class Licenses(object):
         else:
             json_data = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_df2d278e89b45c8ea0ca0a945c001f08_v2_2_3_3', json_data)
+        return self._object_factory('bpm_df2d278e89b45c8ea0ca0a945c001f08_v2_2_2_3', json_data)
 
     def license_usage_details(self,
                               device_type,
@@ -726,7 +720,7 @@ class Licenses(object):
                               virtual_account_name,
                               headers=None,
                               **request_parameters):
-        """Get count of purchased and in use Cisco DNA and Network licenses. .
+        """Get count of purchased and in use DNA and Network licenses. .
 
         Args:
             smart_account_id(basestring): smart_account_id path parameter. Id of smart account .
@@ -787,4 +781,4 @@ class Licenses(object):
         else:
             json_data = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_e55ecbbda454c6a01d905e6f4cce16_v2_2_3_3', json_data)
+        return self._object_factory('bpm_e55ecbbda454c6a01d905e6f4cce16_v2_2_2_3', json_data)
