@@ -22,13 +22,7 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 
-
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-    unicode_literals,
-)
+from __future__ import absolute_import, division, print_function, unicode_literals
 
 from builtins import *
 
@@ -36,15 +30,15 @@ from past.builtins import basestring
 
 from ...restsession import RestSession
 from ...utils import (
+    apply_path_params,
     check_type,
     dict_from_items_with_values,
-    apply_path_params,
     dict_of_str,
 )
 
 
 class EventManagement(object):
-    """Cisco DNA Center Event Management API (version: 2.2.2.3).
+    """Cisco DNA Center Event Management API (version: 2.2.3.3).
 
     Wraps the DNA Center Event Management
     API and exposes the API as native Python
@@ -238,7 +232,7 @@ class EventManagement(object):
         else:
             json_data = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_f8e3a0674c15fd58cd78f42dca37c7c_v2_2_2_3', json_data)
+        return self._object_factory('bpm_f8e3a0674c15fd58cd78f42dca37c7c_v2_2_3_3', json_data)
 
     def get_auditlog_summary(self,
                              category=None,
@@ -394,7 +388,7 @@ class EventManagement(object):
         else:
             json_data = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_ea7c0220d55ae9e1a51d6823ce862_v2_2_2_3', json_data)
+        return self._object_factory('bpm_ea7c0220d55ae9e1a51d6823ce862_v2_2_3_3', json_data)
 
     def get_auditlog_records(self,
                              category=None,
@@ -567,7 +561,7 @@ class EventManagement(object):
         else:
             json_data = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_b0aa5a61f64a5da997dfe05bc8a4a64f_v2_2_2_3', json_data)
+        return self._object_factory('bpm_b0aa5a61f64a5da997dfe05bc8a4a64f_v2_2_3_3', json_data)
 
     def get_status_api_for_events(self,
                                   execution_id,
@@ -622,7 +616,7 @@ class EventManagement(object):
         else:
             json_data = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_e1bd67a1a0225713ab23f0d0d3ceb4f6_v2_2_2_3', json_data)
+        return self._object_factory('bpm_e1bd67a1a0225713ab23f0d0d3ceb4f6_v2_2_3_3', json_data)
 
     def get_notifications(self,
                           category=None,
@@ -738,7 +732,7 @@ class EventManagement(object):
         else:
             json_data = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_c641f481dd285301861010da8d6fbf9f_v2_2_2_3', json_data)
+        return self._object_factory('bpm_c641f481dd285301861010da8d6fbf9f_v2_2_3_3', json_data)
 
     def count_of_notifications(self,
                                category=None,
@@ -833,7 +827,7 @@ class EventManagement(object):
         else:
             json_data = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_fd269fe156e4b5ad3f4210b7b168_v2_2_2_3', json_data)
+        return self._object_factory('bpm_fd269fe156e4b5ad3f4210b7b168_v2_2_3_3', json_data)
 
     def get_event_subscriptions(self,
                                 event_ids=None,
@@ -912,7 +906,7 @@ class EventManagement(object):
         else:
             json_data = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_d7d4e55d6bbb21c34ce863a131_v2_2_2_3', json_data)
+        return self._object_factory('bpm_d7d4e55d6bbb21c34ce863a131_v2_2_3_3', json_data)
 
     def delete_event_subscriptions(self,
                                    subscriptions,
@@ -968,7 +962,7 @@ class EventManagement(object):
         else:
             json_data = self._session.delete(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_a0e0b1772dfc5a02a96a9f6ee6e2579b_v2_2_2_3', json_data)
+        return self._object_factory('bpm_a0e0b1772dfc5a02a96a9f6ee6e2579b_v2_2_3_3', json_data)
 
     def update_event_subscriptions(self,
                                    headers=None,
@@ -1012,7 +1006,7 @@ class EventManagement(object):
         }
         _payload = payload or []
         if active_validation:
-            self._request_validator('jsd_dfda5beca4cc5437876bff366493ebf0_v2_2_2_3')\
+            self._request_validator('jsd_dfda5beca4cc5437876bff366493ebf0_v2_2_3_3')\
                 .validate(_payload)
 
         with_custom_headers = False
@@ -1031,7 +1025,7 @@ class EventManagement(object):
             json_data = self._session.put(endpoint_full_url, params=_params,
                                           json=_payload)
 
-        return self._object_factory('bpm_dfda5beca4cc5437876bff366493ebf0_v2_2_2_3', json_data)
+        return self._object_factory('bpm_dfda5beca4cc5437876bff366493ebf0_v2_2_3_3', json_data)
 
     def create_event_subscriptions(self,
                                    headers=None,
@@ -1075,7 +1069,7 @@ class EventManagement(object):
         }
         _payload = payload or []
         if active_validation:
-            self._request_validator('jsd_fcc151af7615a84adf48b714d146192_v2_2_2_3')\
+            self._request_validator('jsd_fcc151af7615a84adf48b714d146192_v2_2_3_3')\
                 .validate(_payload)
 
         with_custom_headers = False
@@ -1094,7 +1088,7 @@ class EventManagement(object):
             json_data = self._session.post(endpoint_full_url, params=_params,
                                            json=_payload)
 
-        return self._object_factory('bpm_fcc151af7615a84adf48b714d146192_v2_2_2_3', json_data)
+        return self._object_factory('bpm_fcc151af7615a84adf48b714d146192_v2_2_3_3', json_data)
 
     def get_email_subscription_details(self,
                                        connector_type,
@@ -1161,7 +1155,7 @@ class EventManagement(object):
         else:
             json_data = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_d420225889bb16f99ec7ba099a_v2_2_2_3', json_data)
+        return self._object_factory('bpm_d420225889bb16f99ec7ba099a_v2_2_3_3', json_data)
 
     def get_rest_webhook_subscription_details(self,
                                               connector_type,
@@ -1228,7 +1222,7 @@ class EventManagement(object):
         else:
             json_data = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_f278c72555e9a56f554b2a21c85_v2_2_2_3', json_data)
+        return self._object_factory('bpm_f278c72555e9a56f554b2a21c85_v2_2_3_3', json_data)
 
     def get_syslog_subscription_details(self,
                                         connector_type,
@@ -1295,7 +1289,7 @@ class EventManagement(object):
         else:
             json_data = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_c0dcb335458a58fa8bc5a485b174427d_v2_2_2_3', json_data)
+        return self._object_factory('bpm_c0dcb335458a58fa8bc5a485b174427d_v2_2_3_3', json_data)
 
     def count_of_event_subscriptions(self,
                                      event_ids,
@@ -1352,7 +1346,7 @@ class EventManagement(object):
         else:
             json_data = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_c538dc50a4555b5fba17b672a89ee1b8_v2_2_2_3', json_data)
+        return self._object_factory('bpm_c538dc50a4555b5fba17b672a89ee1b8_v2_2_3_3', json_data)
 
     def create_email_event_subscription(self,
                                         headers=None,
@@ -1399,7 +1393,7 @@ class EventManagement(object):
         }
         _payload = payload or []
         if active_validation:
-            self._request_validator('jsd_e69d02d71905aecbd10b782469efbda_v2_2_2_3')\
+            self._request_validator('jsd_e69d02d71905aecbd10b782469efbda_v2_2_3_3')\
                 .validate(_payload)
 
         with_custom_headers = False
@@ -1418,7 +1412,7 @@ class EventManagement(object):
             json_data = self._session.post(endpoint_full_url, params=_params,
                                            json=_payload)
 
-        return self._object_factory('bpm_e69d02d71905aecbd10b782469efbda_v2_2_2_3', json_data)
+        return self._object_factory('bpm_e69d02d71905aecbd10b782469efbda_v2_2_3_3', json_data)
 
     def update_email_event_subscription(self,
                                         headers=None,
@@ -1462,7 +1456,7 @@ class EventManagement(object):
         }
         _payload = payload or []
         if active_validation:
-            self._request_validator('jsd_f8b4842604b65658afb34b4f124db469_v2_2_2_3')\
+            self._request_validator('jsd_f8b4842604b65658afb34b4f124db469_v2_2_3_3')\
                 .validate(_payload)
 
         with_custom_headers = False
@@ -1481,7 +1475,7 @@ class EventManagement(object):
             json_data = self._session.put(endpoint_full_url, params=_params,
                                           json=_payload)
 
-        return self._object_factory('bpm_f8b4842604b65658afb34b4f124db469_v2_2_2_3', json_data)
+        return self._object_factory('bpm_f8b4842604b65658afb34b4f124db469_v2_2_3_3', json_data)
 
     def get_email_event_subscriptions(self,
                                       event_ids=None,
@@ -1560,7 +1554,7 @@ class EventManagement(object):
         else:
             json_data = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_bc212b5ee1f252479f35e8dd58319f17_v2_2_2_3', json_data)
+        return self._object_factory('bpm_bc212b5ee1f252479f35e8dd58319f17_v2_2_3_3', json_data)
 
     def create_rest_webhook_event_subscription(self,
                                                headers=None,
@@ -1607,7 +1601,7 @@ class EventManagement(object):
         }
         _payload = payload or []
         if active_validation:
-            self._request_validator('jsd_f41eb48a0da56949cfaddeecb51ab66_v2_2_2_3')\
+            self._request_validator('jsd_f41eb48a0da56949cfaddeecb51ab66_v2_2_3_3')\
                 .validate(_payload)
 
         with_custom_headers = False
@@ -1626,7 +1620,7 @@ class EventManagement(object):
             json_data = self._session.post(endpoint_full_url, params=_params,
                                            json=_payload)
 
-        return self._object_factory('bpm_f41eb48a0da56949cfaddeecb51ab66_v2_2_2_3', json_data)
+        return self._object_factory('bpm_f41eb48a0da56949cfaddeecb51ab66_v2_2_3_3', json_data)
 
     def get_rest_webhook_event_subscriptions(self,
                                              event_ids=None,
@@ -1705,7 +1699,7 @@ class EventManagement(object):
         else:
             json_data = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_ee2008494d158e7bff7f106519a64c5_v2_2_2_3', json_data)
+        return self._object_factory('bpm_ee2008494d158e7bff7f106519a64c5_v2_2_3_3', json_data)
 
     def update_rest_webhook_event_subscription(self,
                                                headers=None,
@@ -1749,7 +1743,7 @@ class EventManagement(object):
         }
         _payload = payload or []
         if active_validation:
-            self._request_validator('jsd_b6581534bb321eaea272365b7_v2_2_2_3')\
+            self._request_validator('jsd_b6581534bb321eaea272365b7_v2_2_3_3')\
                 .validate(_payload)
 
         with_custom_headers = False
@@ -1768,7 +1762,7 @@ class EventManagement(object):
             json_data = self._session.put(endpoint_full_url, params=_params,
                                           json=_payload)
 
-        return self._object_factory('bpm_b6581534bb321eaea272365b7_v2_2_2_3', json_data)
+        return self._object_factory('bpm_b6581534bb321eaea272365b7_v2_2_3_3', json_data)
 
     def update_syslog_event_subscription(self,
                                          headers=None,
@@ -1815,7 +1809,7 @@ class EventManagement(object):
         }
         _payload = payload or []
         if active_validation:
-            self._request_validator('jsd_d8fc92ddeab597ebb50ea003a6d46bd_v2_2_2_3')\
+            self._request_validator('jsd_d8fc92ddeab597ebb50ea003a6d46bd_v2_2_3_3')\
                 .validate(_payload)
 
         with_custom_headers = False
@@ -1834,7 +1828,7 @@ class EventManagement(object):
             json_data = self._session.put(endpoint_full_url, params=_params,
                                           json=_payload)
 
-        return self._object_factory('bpm_d8fc92ddeab597ebb50ea003a6d46bd_v2_2_2_3', json_data)
+        return self._object_factory('bpm_d8fc92ddeab597ebb50ea003a6d46bd_v2_2_3_3', json_data)
 
     def create_syslog_event_subscription(self,
                                          headers=None,
@@ -1878,7 +1872,7 @@ class EventManagement(object):
         }
         _payload = payload or []
         if active_validation:
-            self._request_validator('jsd_fb5a8c0075563491622171958074bf_v2_2_2_3')\
+            self._request_validator('jsd_fb5a8c0075563491622171958074bf_v2_2_3_3')\
                 .validate(_payload)
 
         with_custom_headers = False
@@ -1897,7 +1891,7 @@ class EventManagement(object):
             json_data = self._session.post(endpoint_full_url, params=_params,
                                            json=_payload)
 
-        return self._object_factory('bpm_fb5a8c0075563491622171958074bf_v2_2_2_3', json_data)
+        return self._object_factory('bpm_fb5a8c0075563491622171958074bf_v2_2_3_3', json_data)
 
     def get_syslog_event_subscriptions(self,
                                        event_ids=None,
@@ -1976,7 +1970,7 @@ class EventManagement(object):
         else:
             json_data = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_c7bed4b4148753e6bc9912e3be135217_v2_2_2_3', json_data)
+        return self._object_factory('bpm_c7bed4b4148753e6bc9912e3be135217_v2_2_3_3', json_data)
 
     def get_events(self,
                    tags,
@@ -2060,7 +2054,7 @@ class EventManagement(object):
         else:
             json_data = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_bf36f1819e61575189c0709efab6e48a_v2_2_2_3', json_data)
+        return self._object_factory('bpm_bf36f1819e61575189c0709efab6e48a_v2_2_3_3', json_data)
 
     def count_of_events(self,
                         tags,
@@ -2121,7 +2115,7 @@ class EventManagement(object):
         else:
             json_data = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_b21d2947d715c198f5e62ba3149839a_v2_2_2_3', json_data)
+        return self._object_factory('bpm_b21d2947d715c198f5e62ba3149839a_v2_2_3_3', json_data)
 
     def get_eventartifacts(self,
                            event_ids=None,
@@ -2208,7 +2202,7 @@ class EventManagement(object):
         else:
             json_data = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_c0e0d76b2561b8f2efd0220f02267_v2_2_2_3', json_data)
+        return self._object_factory('bpm_c0e0d76b2561b8f2efd0220f02267_v2_2_3_3', json_data)
 
     def eventartifact_count(self,
                             headers=None,
@@ -2258,4 +2252,4 @@ class EventManagement(object):
         else:
             json_data = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_a137e0b583c85ffe80fbbd85b480bf15_v2_2_2_3', json_data)
+        return self._object_factory('bpm_a137e0b583c85ffe80fbbd85b480bf15_v2_2_3_3', json_data)
