@@ -22,13 +22,7 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 
-
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-    unicode_literals,
-)
+from __future__ import absolute_import, division, print_function, unicode_literals
 
 from builtins import *
 
@@ -36,9 +30,9 @@ from past.builtins import basestring
 
 from ...restsession import RestSession
 from ...utils import (
+    apply_path_params,
     check_type,
     dict_from_items_with_values,
-    apply_path_params,
     dict_of_str,
 )
 
@@ -98,9 +92,8 @@ class FabricWireless(object):
                 support for parameters that may be added in the future).
 
         Returns:
-            list: JSON response. A list of MyDict objects.
-            Access the object's properties by using the dot notation
-            or the bracket notation.
+            MyDict: JSON response. Access the object's properties by using
+            the dot notation or the bracket notation.
 
         Raises:
             TypeError: If the parameter types are incorrect.
@@ -182,9 +175,8 @@ class FabricWireless(object):
                 support for parameters that may be added in the future).
 
         Returns:
-            list: JSON response. A list of MyDict objects.
-            Access the object's properties by using the dot notation
-            or the bracket notation.
+            MyDict: JSON response. Access the object's properties by using
+            the dot notation or the bracket notation.
 
         Raises:
             TypeError: If the parameter types are incorrect.
@@ -381,9 +373,8 @@ class FabricWireless(object):
                 support for parameters that may be added in the future).
 
         Returns:
-            list: JSON response. A list of MyDict objects.
-            Access the object's properties by using the dot notation
-            or the bracket notation.
+            MyDict: JSON response. Access the object's properties by using
+            the dot notation or the bracket notation.
 
         Raises:
             TypeError: If the parameter types are incorrect.
