@@ -22,13 +22,7 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 
-
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-    unicode_literals,
-)
+from __future__ import absolute_import, division, print_function, unicode_literals
 
 from builtins import *
 
@@ -36,15 +30,15 @@ from past.builtins import basestring
 
 from ...restsession import RestSession
 from ...utils import (
+    apply_path_params,
     check_type,
     dict_from_items_with_values,
-    apply_path_params,
     dict_of_str,
 )
 
 
 class Sensors(object):
-    """Cisco DNA Center Sensors API (version: 2.1.2).
+    """Cisco DNA Center Sensors API (version: 2.3.3.0).
 
     Wraps the DNA Center Sensors
     API and exposes the API as native Python
@@ -72,25 +66,20 @@ class Sensors(object):
         self._object_factory = object_factory
         self._request_validator = request_validator
 
-    def create_sensor_test_template(self,
-                                    apCoverage=None,
-                                    connection=None,
-                                    modelVersion=None,
-                                    name=None,
-                                    ssids=None,
-                                    headers=None,
-                                    payload=None,
-                                    active_validation=True,
-                                    **request_parameters):
-        """Intent API to create a SENSOR test template with a new SSID,
-        existing SSID, or both new and existing SSID.
+    def edit_sensor_test_template(self,
+                                  locationInfoList=None,
+                                  schedule=None,
+                                  templateName=None,
+                                  headers=None,
+                                  payload=None,
+                                  active_validation=True,
+                                  **request_parameters):
+        """Intent API to deploy, schedule, or edit and existing SENSOR test template .
 
         Args:
-            apCoverage(list): Ap Coverage, property of the request body (list of objects).
-            connection(string): Connection, property of the request body.
-            modelVersion(number): modelVersion, property of the request body.
-            name(string): Name, property of the request body.
-            ssids(list): Ssids, property of the request body (list of objects).
+            locationInfoList(list): Sensors's locationInfoList (list of objects).
+            schedule(object): Sensors's schedule.
+            templateName(string): Sensors's Template Name.
             headers(dict): Dictionary of HTTP Headers to send with the Request
                 .
             payload(dict): A JSON serializable Python object to send in the
@@ -123,7 +112,88 @@ class Sensors(object):
 
         path_params = {
         }
+        _payload = {
+            'templateName':
+                templateName,
+            'locationInfoList':
+                locationInfoList,
+            'schedule':
+                schedule,
+        }
+        _payload.update(payload or {})
+        _payload = dict_from_items_with_values(_payload)
+        if active_validation:
+            self._request_validator('jsd_e2f9718de3d050819cdc6355a3a43200_v2_3_3_0')\
+                .validate(_payload)
 
+        with_custom_headers = False
+        _headers = self._session.headers or {}
+        if headers:
+            _headers.update(dict_of_str(headers))
+            with_custom_headers = True
+
+        e_url = ('/dna/intent/api/v1/AssuranceScheduleSensorTest')
+        endpoint_full_url = apply_path_params(e_url, path_params)
+        if with_custom_headers:
+            json_data = self._session.put(endpoint_full_url, params=_params,
+                                          json=_payload,
+                                          headers=_headers)
+        else:
+            json_data = self._session.put(endpoint_full_url, params=_params,
+                                          json=_payload)
+
+        return self._object_factory('bpm_e2f9718de3d050819cdc6355a3a43200_v2_3_3_0', json_data)
+
+    def create_sensor_test_template(self,
+                                    apCoverage=None,
+                                    connection=None,
+                                    modelVersion=None,
+                                    name=None,
+                                    ssids=None,
+                                    headers=None,
+                                    payload=None,
+                                    active_validation=True,
+                                    **request_parameters):
+        """Intent API to create a SENSOR test template with a new SSID, existing SSID, or both new and existing SSID .
+
+        Args:
+            apCoverage(list): Sensors's apCoverage (list of objects).
+            connection(string): Sensors's Connection.
+            modelVersion(integer): Sensors's Model Version.
+            name(string): Sensors's Name.
+            ssids(list): Sensors's ssids (list of objects).
+            headers(dict): Dictionary of HTTP Headers to send with the Request
+                .
+            payload(dict): A JSON serializable Python object to send in the
+                body of the Request.
+            active_validation(bool): Enable/Disable payload validation.
+                Defaults to True.
+            **request_parameters: Additional request parameters (provides
+                support for parameters that may be added in the future).
+
+        Returns:
+            MyDict: JSON response. Access the object's properties by using
+            the dot notation or the bracket notation.
+
+        Raises:
+            TypeError: If the parameter types are incorrect.
+            MalformedRequest: If the request body created is invalid.
+            ApiError: If the DNA Center cloud returns an error.
+        """
+        check_type(headers, dict)
+        check_type(payload, dict)
+        if headers is not None:
+            if 'X-Auth-Token' in headers:
+                check_type(headers.get('X-Auth-Token'),
+                           basestring, may_be_none=False)
+
+        _params = {
+        }
+        _params.update(request_parameters)
+        _params = dict_from_items_with_values(_params)
+
+        path_params = {
+        }
         _payload = {
             'ssids':
                 ssids,
@@ -139,7 +209,7 @@ class Sensors(object):
         _payload.update(payload or {})
         _payload = dict_from_items_with_values(_payload)
         if active_validation:
-            self._request_validator('jsd_08bd88834a68a2e6_v2_1_2')\
+            self._request_validator('jsd_f7dd6a6cf8d57499168aae05847ad34_v2_3_3_0')\
                 .validate(_payload)
 
         with_custom_headers = False
@@ -158,13 +228,13 @@ class Sensors(object):
             json_data = self._session.post(endpoint_full_url, params=_params,
                                            json=_payload)
 
-        return self._object_factory('bpm_08bd88834a68a2e6_v2_1_2', json_data)
+        return self._object_factory('bpm_f7dd6a6cf8d57499168aae05847ad34_v2_3_3_0', json_data)
 
     def delete_sensor_test(self,
                            template_name=None,
                            headers=None,
                            **request_parameters):
-        """Intent API to delete an existing SENSOR test template.
+        """Intent API to delete an existing SENSOR test template .
 
         Args:
             template_name(basestring): templateName query parameter.
@@ -213,88 +283,13 @@ class Sensors(object):
         else:
             json_data = self._session.delete(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_5bbb28ff442a825f_v2_1_2', json_data)
-
-    def duplicate_sensor_test_template(self,
-                                       newTemplateName=None,
-                                       templateName=None,
-                                       headers=None,
-                                       payload=None,
-                                       active_validation=True,
-                                       **request_parameters):
-        """Intent API to duplicate an existing SENSOR test template.
-
-        Args:
-            newTemplateName(string): New Template Name, property of the request body.
-            templateName(string): Template Name, property of the request body.
-            headers(dict): Dictionary of HTTP Headers to send with the Request
-                .
-            payload(dict): A JSON serializable Python object to send in the
-                body of the Request.
-            active_validation(bool): Enable/Disable payload validation.
-                Defaults to True.
-            **request_parameters: Additional request parameters (provides
-                support for parameters that may be added in the future).
-
-        Returns:
-            MyDict: JSON response. Access the object's properties by using
-            the dot notation or the bracket notation.
-
-        Raises:
-            TypeError: If the parameter types are incorrect.
-            MalformedRequest: If the request body created is invalid.
-            ApiError: If the DNA Center cloud returns an error.
-        """
-        check_type(headers, dict)
-        check_type(payload, dict)
-        if headers is not None:
-            if 'X-Auth-Token' in headers:
-                check_type(headers.get('X-Auth-Token'),
-                           basestring, may_be_none=False)
-
-        _params = {
-        }
-        _params.update(request_parameters)
-        _params = dict_from_items_with_values(_params)
-
-        path_params = {
-        }
-
-        _payload = {
-            'templateName':
-                templateName,
-            'newTemplateName':
-                newTemplateName,
-        }
-        _payload.update(payload or {})
-        _payload = dict_from_items_with_values(_payload)
-        if active_validation:
-            self._request_validator('jsd_85a2883749099021_v2_1_2')\
-                .validate(_payload)
-
-        with_custom_headers = False
-        _headers = self._session.headers or {}
-        if headers:
-            _headers.update(dict_of_str(headers))
-            with_custom_headers = True
-
-        e_url = ('/dna/intent/api/v1/sensorTestTemplate')
-        endpoint_full_url = apply_path_params(e_url, path_params)
-        if with_custom_headers:
-            json_data = self._session.put(endpoint_full_url, params=_params,
-                                          json=_payload,
-                                          headers=_headers)
-        else:
-            json_data = self._session.put(endpoint_full_url, params=_params,
-                                          json=_payload)
-
-        return self._object_factory('bpm_85a2883749099021_v2_1_2', json_data)
+        return self._object_factory('bpm_a1c0ac4386555300b7f4a541d8dba625_v2_3_3_0', json_data)
 
     def sensors(self,
                 site_id=None,
                 headers=None,
                 **request_parameters):
-        """Intent API to get a list of SENSOR devices.
+        """Intent API to get a list of SENSOR devices .
 
         Args:
             site_id(basestring): siteId query parameter.
@@ -343,87 +338,7 @@ class Sensors(object):
         else:
             json_data = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_71a12bb745699cc5_v2_1_2', json_data)
-
-    def edit_sensor_test_template(self,
-                                  locationInfoList=None,
-                                  schedule=None,
-                                  templateName=None,
-                                  headers=None,
-                                  payload=None,
-                                  active_validation=True,
-                                  **request_parameters):
-        """Intent API to deploy, schedule, or edit and existing SENSOR test
-        template.
-
-        Args:
-            locationInfoList(list): Location Info List, property of the request body (list of objects).
-            schedule(object): Schedule, property of the request body.
-            templateName(string): Template Name, property of the request body.
-            headers(dict): Dictionary of HTTP Headers to send with the Request
-                .
-            payload(dict): A JSON serializable Python object to send in the
-                body of the Request.
-            active_validation(bool): Enable/Disable payload validation.
-                Defaults to True.
-            **request_parameters: Additional request parameters (provides
-                support for parameters that may be added in the future).
-
-        Returns:
-            MyDict: JSON response. Access the object's properties by using
-            the dot notation or the bracket notation.
-
-        Raises:
-            TypeError: If the parameter types are incorrect.
-            MalformedRequest: If the request body created is invalid.
-            ApiError: If the DNA Center cloud returns an error.
-        """
-        check_type(headers, dict)
-        check_type(payload, dict)
-        if headers is not None:
-            if 'X-Auth-Token' in headers:
-                check_type(headers.get('X-Auth-Token'),
-                           basestring, may_be_none=False)
-
-        _params = {
-        }
-        _params.update(request_parameters)
-        _params = dict_from_items_with_values(_params)
-
-        path_params = {
-        }
-
-        _payload = {
-            'templateName':
-                templateName,
-            'locationInfoList':
-                locationInfoList,
-            'schedule':
-                schedule,
-        }
-        _payload.update(payload or {})
-        _payload = dict_from_items_with_values(_payload)
-        if active_validation:
-            self._request_validator('jsd_c085eaf54f89ba34_v2_1_2')\
-                .validate(_payload)
-
-        with_custom_headers = False
-        _headers = self._session.headers or {}
-        if headers:
-            _headers.update(dict_of_str(headers))
-            with_custom_headers = True
-
-        e_url = ('/dna/intent/api/v1/AssuranceScheduleSensorTest')
-        endpoint_full_url = apply_path_params(e_url, path_params)
-        if with_custom_headers:
-            json_data = self._session.put(endpoint_full_url, params=_params,
-                                          json=_payload,
-                                          headers=_headers)
-        else:
-            json_data = self._session.put(endpoint_full_url, params=_params,
-                                          json=_payload)
-
-        return self._object_factory('bpm_c085eaf54f89ba34_v2_1_2', json_data)
+        return self._object_factory('bpm_cda740c5bdc92fd150c334d0e4e_v2_3_3_0', json_data)
 
     def run_now_sensor_test(self,
                             templateName=None,
@@ -431,10 +346,10 @@ class Sensors(object):
                             payload=None,
                             active_validation=True,
                             **request_parameters):
-        """Intent API to run a deployed SENSOR test.
+        """Intent API to run a deployed SENSOR test .
 
         Args:
-            templateName(string): Template Name, property of the request body.
+            templateName(string): Sensors's Template Name.
             headers(dict): Dictionary of HTTP Headers to send with the Request
                 .
             payload(dict): A JSON serializable Python object to send in the
@@ -467,7 +382,6 @@ class Sensors(object):
 
         path_params = {
         }
-
         _payload = {
             'templateName':
                 templateName,
@@ -475,7 +389,7 @@ class Sensors(object):
         _payload.update(payload or {})
         _payload = dict_from_items_with_values(_payload)
         if active_validation:
-            self._request_validator('jsd_f1a7a8e74cf99c8f_v2_1_2')\
+            self._request_validator('jsd_cfadc5e4c912588389f4f63d2fb6e4ed_v2_3_3_0')\
                 .validate(_payload)
 
         with_custom_headers = False
@@ -494,4 +408,78 @@ class Sensors(object):
             json_data = self._session.put(endpoint_full_url, params=_params,
                                           json=_payload)
 
-        return self._object_factory('bpm_f1a7a8e74cf99c8f_v2_1_2', json_data)
+        return self._object_factory('bpm_cfadc5e4c912588389f4f63d2fb6e4ed_v2_3_3_0', json_data)
+
+    def duplicate_sensor_test_template(self,
+                                       newTemplateName=None,
+                                       templateName=None,
+                                       headers=None,
+                                       payload=None,
+                                       active_validation=True,
+                                       **request_parameters):
+        """Intent API to duplicate an existing SENSOR test template .
+
+        Args:
+            newTemplateName(string): Sensors's New Template Name.
+            templateName(string): Sensors's Template Name.
+            headers(dict): Dictionary of HTTP Headers to send with the Request
+                .
+            payload(dict): A JSON serializable Python object to send in the
+                body of the Request.
+            active_validation(bool): Enable/Disable payload validation.
+                Defaults to True.
+            **request_parameters: Additional request parameters (provides
+                support for parameters that may be added in the future).
+
+        Returns:
+            MyDict: JSON response. Access the object's properties by using
+            the dot notation or the bracket notation.
+
+        Raises:
+            TypeError: If the parameter types are incorrect.
+            MalformedRequest: If the request body created is invalid.
+            ApiError: If the DNA Center cloud returns an error.
+        """
+        check_type(headers, dict)
+        check_type(payload, dict)
+        if headers is not None:
+            if 'X-Auth-Token' in headers:
+                check_type(headers.get('X-Auth-Token'),
+                           basestring, may_be_none=False)
+
+        _params = {
+        }
+        _params.update(request_parameters)
+        _params = dict_from_items_with_values(_params)
+
+        path_params = {
+        }
+        _payload = {
+            'templateName':
+                templateName,
+            'newTemplateName':
+                newTemplateName,
+        }
+        _payload.update(payload or {})
+        _payload = dict_from_items_with_values(_payload)
+        if active_validation:
+            self._request_validator('jsd_a352f6280e445075b3ea7cbf868c2d94_v2_3_3_0')\
+                .validate(_payload)
+
+        with_custom_headers = False
+        _headers = self._session.headers or {}
+        if headers:
+            _headers.update(dict_of_str(headers))
+            with_custom_headers = True
+
+        e_url = ('/dna/intent/api/v1/sensorTestTemplate')
+        endpoint_full_url = apply_path_params(e_url, path_params)
+        if with_custom_headers:
+            json_data = self._session.put(endpoint_full_url, params=_params,
+                                          json=_payload,
+                                          headers=_headers)
+        else:
+            json_data = self._session.put(endpoint_full_url, params=_params,
+                                          json=_payload)
+
+        return self._object_factory('bpm_a352f6280e445075b3ea7cbf868c2d94_v2_3_3_0', json_data)
