@@ -22,19 +22,14 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 
+from __future__ import absolute_import, division, print_function, unicode_literals
 
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-    unicode_literals,
-)
+import json
+from builtins import *
 
 import fastjsonschema
-import json
-from dnacentersdk.exceptions import MalformedRequest
 
-from builtins import *
+from dnacentersdk.exceptions import MalformedRequest
 
 
 class JSONSchemaValidator828828F44F28Bd0D(object):
@@ -44,12 +39,6 @@ class JSONSchemaValidator828828F44F28Bd0D(object):
         self._validator = fastjsonschema.compile(json.loads(
             '''{
                 "properties": {
-                "callbackUrl": {
-                "type": [
-                "string",
-                "null"
-                ]
-                },
                 "provisioning": {
                 "items": {
                 "properties": {
@@ -235,6 +224,12 @@ class JSONSchemaValidator828828F44F28Bd0D(object):
                 "null"
                 ]
                 },
+                "parentPoolName": {
+                "type": [
+                "string",
+                "null"
+                ]
+                },
                 "type": {
                 "enum": [
                 "Lan",
@@ -266,6 +261,42 @@ class JSONSchemaValidator828828F44F28Bd0D(object):
                 "null"
                 ]
                 },
+                "templateParam": {
+                "properties": {
+                "asav": {
+                "properties": {
+                "var1": {
+                "type": [
+                "string",
+                "null"
+                ]
+                }
+                },
+                "type": [
+                "object",
+                "null"
+                ]
+                },
+                "nfvis": {
+                "properties": {
+                "var1": {
+                "type": [
+                "string",
+                "null"
+                ]
+                }
+                },
+                "type": [
+                "object",
+                "null"
+                ]
+                }
+                },
+                "type": [
+                "object",
+                "null"
+                ]
+                },
                 "vlan": {
                 "items": {
                 "properties": {
@@ -315,36 +346,6 @@ class JSONSchemaValidator828828F44F28Bd0D(object):
                 "null"
                 ]
                 },
-                "networksettings": {
-                "properties": {
-                "ipPool": {
-                "properties": {
-                "globalPool": {
-                "properties": {
-                "name": {
-                "type": [
-                "string",
-                "null"
-                ]
-                }
-                },
-                "type": [
-                "object",
-                "null"
-                ]
-                }
-                },
-                "type": [
-                "object",
-                "null"
-                ]
-                }
-                },
-                "type": [
-                "object",
-                "null"
-                ]
-                },
                 "site": {
                 "properties": {
                 "area": {
@@ -375,20 +376,18 @@ class JSONSchemaValidator828828F44F28Bd0D(object):
                 "null"
                 ]
                 },
-                "name": {
+                "latitude": {
                 "type": [
-                "string",
+                "number",
                 "null"
                 ]
-                }
                 },
+                "longitude": {
                 "type": [
-                "object",
+                "number",
                 "null"
                 ]
                 },
-                "floor": {
-                "properties": {
                 "name": {
                 "type": [
                 "string",
@@ -407,6 +406,50 @@ class JSONSchemaValidator828828F44F28Bd0D(object):
                 "null"
                 ]
                 },
+                "floor": {
+                "properties": {
+                "height": {
+                "type": [
+                "number",
+                "null"
+                ]
+                },
+                "length": {
+                "type": [
+                "number",
+                "null"
+                ]
+                },
+                "name": {
+                "type": [
+                "string",
+                "null"
+                ]
+                },
+                "parentName": {
+                "type": [
+                "string",
+                "null"
+                ]
+                },
+                "rfModel": {
+                "type": [
+                "string",
+                "null"
+                ]
+                },
+                "width": {
+                "type": [
+                "number",
+                "null"
+                ]
+                }
+                },
+                "type": [
+                "object",
+                "null"
+                ]
+                },
                 "siteProfileName": {
                 "type": [
                 "string",
@@ -418,42 +461,6 @@ class JSONSchemaValidator828828F44F28Bd0D(object):
                 "object",
                 "null"
                 ]
-                },
-                "templateParam": {
-                "properties": {
-                "asav": {
-                "properties": {
-                "var1": {
-                "type": [
-                "string",
-                "null"
-                ]
-                }
-                },
-                "type": [
-                "object",
-                "null"
-                ]
-                },
-                "nfvis": {
-                "properties": {
-                "var1": {
-                "type": [
-                "string",
-                "null"
-                ]
-                }
-                },
-                "type": [
-                "object",
-                "null"
-                ]
-                }
-                },
-                "type": [
-                "object",
-                "null"
-                ]
                 }
                 },
                 "type": [
@@ -468,37 +475,6 @@ class JSONSchemaValidator828828F44F28Bd0D(object):
                 "siteProfile": {
                 "items": {
                 "properties": {
-                "customTemplate": {
-                "items": {
-                "properties": {
-                "deviceType": {
-                "enum": [
-                "NFVIS",
-                "ASAv",
-                null
-                ],
-                "type": [
-                "string",
-                "null"
-                ]
-                },
-                "template": {
-                "type": [
-                "string",
-                "null"
-                ]
-                }
-                },
-                "type": [
-                "object",
-                "null"
-                ]
-                },
-                "type": [
-                "array",
-                "null"
-                ]
-                },
                 "device": {
                 "items": {
                 "properties": {
@@ -592,6 +568,37 @@ class JSONSchemaValidator828828F44F28Bd0D(object):
                 "null"
                 ]
                 },
+                "customTemplate": {
+                "items": {
+                "properties": {
+                "deviceType": {
+                "enum": [
+                "NFVIS",
+                "ASAv",
+                null
+                ],
+                "type": [
+                "string",
+                "null"
+                ]
+                },
+                "template": {
+                "type": [
+                "string",
+                "null"
+                ]
+                }
+                },
+                "type": [
+                "object",
+                "null"
+                ]
+                },
+                "type": [
+                "array",
+                "null"
+                ]
+                },
                 "deviceType": {
                 "enum": [
                 "ENCS5100",
