@@ -22,19 +22,14 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 
+from __future__ import absolute_import, division, print_function, unicode_literals
 
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-    unicode_literals,
-)
+import json
+from builtins import *
 
 import fastjsonschema
-import json
-from dnacentersdk.exceptions import MalformedRequest
 
-from builtins import *
+from dnacentersdk.exceptions import MalformedRequest
 
 
 class JSONSchemaValidator6F9CDa9A465884B4(object):
@@ -179,12 +174,6 @@ class JSONSchemaValidator6F9CDa9A465884B4(object):
                 "null"
                 ]
                 },
-                "disk": {
-                "type": [
-                "string",
-                "null"
-                ]
-                },
                 "mode": {
                 "type": [
                 "string",
@@ -556,12 +545,6 @@ class JSONSchemaValidator6F9CDa9A465884B4(object):
                 "null"
                 ]
                 },
-                "imageName": {
-                "type": [
-                "string",
-                "null"
-                ]
-                },
                 "name": {
                 "type": [
                 "string",
@@ -573,32 +556,6 @@ class JSONSchemaValidator6F9CDa9A465884B4(object):
                 "string",
                 "null"
                 ]
-                },
-                "topology": {
-                "properties": {
-                "assignIp": {
-                "type": [
-                "string",
-                "null"
-                ]
-                },
-                "name": {
-                "type": [
-                "string",
-                "null"
-                ]
-                },
-                "type": {
-                "type": [
-                "string",
-                "null"
-                ]
-                }
-                },
-                "type": [
-                "object",
-                "null"
-                ]
                 }
                 },
                 "type": [
@@ -704,56 +661,18 @@ class JSONSchemaValidator6F9CDa9A465884B4(object):
                 "services": {
                 "items": {
                 "properties": {
-                "imageName": {
-                "type": [
-                "string",
-                "null"
-                ]
-                },
                 "mode": {
                 "type": [
                 "string",
                 "null"
                 ]
                 },
-                "name": {
-                "type": [
-                "string",
-                "null"
-                ]
-                },
                 "profile": {
                 "type": [
                 "string",
                 "null"
                 ]
                 },
-                "topology": {
-                "properties": {
-                "assignIp": {
-                "type": [
-                "string",
-                "null"
-                ]
-                },
-                "name": {
-                "type": [
-                "string",
-                "null"
-                ]
-                },
-                "type": {
-                "type": [
-                "string",
-                "null"
-                ]
-                }
-                },
-                "type": [
-                "object",
-                "null"
-                ]
-                },
                 "type": {
                 "enum": [
                 "isr",
