@@ -22,19 +22,14 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 
+from __future__ import absolute_import, division, print_function, unicode_literals
 
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-    unicode_literals,
-)
+import json
+from builtins import *
 
 import fastjsonschema
-import json
-from dnacentersdk.exceptions import MalformedRequest
 
-from builtins import *
+from dnacentersdk.exceptions import MalformedRequest
 
 
 class JSONSchemaValidatorF04B76067507B9384E409E9431Ef3(object):
@@ -48,6 +43,17 @@ class JSONSchemaValidatorF04B76067507B9384E409E9431Ef3(object):
                 "_id": {
                 "type": "string"
                 },
+                "dayZeroConfig": {
+                "properties": {
+                "config": {
+                "type": "string"
+                }
+                },
+                "type": "object"
+                },
+                "dayZeroConfigPreview": {
+                "type": "object"
+                },
                 "deviceInfo": {
                 "properties": {
                 "aaaCredentials": {
@@ -62,7 +68,7 @@ class JSONSchemaValidatorF04B76067507B9384E409E9431Ef3(object):
                 "type": "object"
                 },
                 "addedOn": {
-                "type": "integer"
+                "type": "number"
                 },
                 "addnMacAddrs": {
                 "items": {
@@ -71,15 +77,14 @@ class JSONSchemaValidatorF04B76067507B9384E409E9431Ef3(object):
                 "type": "array"
                 },
                 "agentType": {
-                "enum": [
-                "POSIX",
-                "IOS"
-                ],
                 "type": "string"
                 },
                 "authStatus": {
                 "type": "string"
                 },
+                "authenticatedMicNumber": {
+                "type": "string"
+                },
                 "authenticatedSudiSerialNo": {
                 "type": "string"
                 },
@@ -90,16 +95,6 @@ class JSONSchemaValidatorF04B76067507B9384E409E9431Ef3(object):
                 "type": "array"
                 },
                 "cmState": {
-                "enum": [
-                "NotContacted",
-                "Contacted",
-                "Disconnected",
-                "SecuringConnection",
-                "SecuredConnection",
-                "Authenticated",
-                "ErrorSecuringConnection",
-                "ErrorAuthenticating"
-                ],
                 "type": "string"
                 },
                 "description":
@@ -125,7 +120,7 @@ class JSONSchemaValidatorF04B76067507B9384E409E9431Ef3(object):
                 "items": {
                 "properties": {
                 "freespace": {
-                "type": "integer"
+                "type": "number"
                 },
                 "name": {
                 "type": "string"
@@ -134,7 +129,7 @@ class JSONSchemaValidatorF04B76067507B9384E409E9431Ef3(object):
                 "type": "boolean"
                 },
                 "size": {
-                "type": "integer"
+                "type": "number"
                 },
                 "type": {
                 "type": "string"
@@ -148,7 +143,7 @@ class JSONSchemaValidatorF04B76067507B9384E409E9431Ef3(object):
                 "type": "array"
                 },
                 "firstContact": {
-                "type": "integer"
+                "type": "number"
                 },
                 "hostname": {
                 "type": "string"
@@ -200,13 +195,13 @@ class JSONSchemaValidatorF04B76067507B9384E409E9431Ef3(object):
                 "type": "array"
                 },
                 "lastContact": {
-                "type": "integer"
+                "type": "number"
                 },
                 "lastSyncTime": {
-                "type": "integer"
+                "type": "number"
                 },
                 "lastUpdateOn": {
-                "type": "integer"
+                "type": "number"
                 },
                 "location": {
                 "properties": {
@@ -273,23 +268,6 @@ class JSONSchemaValidatorF04B76067507B9384E409E9431Ef3(object):
                 "type": "array"
                 },
                 "onbState": {
-                "enum": [
-                "NotContacted",
-                "Connecting",
-                "ErrorSecuringConnection",
-                "ErrorAuthenticating",
-                "Initializing",
-                "Initialized",
-                "ErrorInitializing",
-                "SudiAuthorizing",
-                "ErrorSudiAuthorizing",
-                "ExecutingWorkflow",
-                "ExecutedWorkflow",
-                "ErrorExecutingWorkflow",
-                "ExecutingReset",
-                "ErrorExecutingReset",
-                "Provisioned"
-                ],
                 "type": "string"
                 },
                 "pid": {
@@ -319,7 +297,7 @@ class JSONSchemaValidatorF04B76067507B9384E409E9431Ef3(object):
                 "type": "object"
                 },
                 "port": {
-                "type": "integer"
+                "type": "number"
                 },
                 "protocol": {
                 "type": "string"
@@ -345,7 +323,7 @@ class JSONSchemaValidatorF04B76067507B9384E409E9431Ef3(object):
                 "type": "object"
                 },
                 "port": {
-                "type": "integer"
+                "type": "number"
                 },
                 "protocol": {
                 "type": "string"
@@ -387,6 +365,12 @@ class JSONSchemaValidatorF04B76067507B9384E409E9431Ef3(object):
                 "serialNumber": {
                 "type": "string"
                 },
+                "siteId": {
+                "type": "string"
+                },
+                "siteName": {
+                "type": "string"
+                },
                 "smartAccountId": {
                 "type": "string"
                 },
@@ -420,7 +404,7 @@ class JSONSchemaValidatorF04B76067507B9384E409E9431Ef3(object):
                 "type": "string"
                 },
                 "priority": {
-                "type": "integer"
+                "type": "number"
                 },
                 "role": {
                 "type": "string"
@@ -432,7 +416,7 @@ class JSONSchemaValidatorF04B76067507B9384E409E9431Ef3(object):
                 "type": "string"
                 },
                 "stackNumber": {
-                "type": "integer"
+                "type": "number"
                 },
                 "state": {
                 "type": "string"
@@ -452,7 +436,7 @@ class JSONSchemaValidatorF04B76067507B9384E409E9431Ef3(object):
                 "type": "boolean"
                 },
                 "totalMemberCount": {
-                "type": "integer"
+                "type": "number"
                 },
                 "validLicenseLevels": {
                 "items": {
@@ -464,14 +448,6 @@ class JSONSchemaValidatorF04B76067507B9384E409E9431Ef3(object):
                 "type": "object"
                 },
                 "state": {
-                "enum": [
-                "Unclaimed",
-                "Planned",
-                "Onboarding",
-                "Provisioned",
-                "Error",
-                "Deleted"
-                ],
                 "type": "string"
                 },
                 "sudiRequired": {
@@ -480,6 +456,12 @@ class JSONSchemaValidatorF04B76067507B9384E409E9431Ef3(object):
                 "tags": {
                 "type": "object"
                 },
+                "userMicNumbers": {
+                "items": {
+                "type": "string"
+                },
+                "type": "array"
+                },
                 "userSudiSerialNos": {
                 "items": {
                 "type": "string"
@@ -527,7 +509,7 @@ class JSONSchemaValidatorF04B76067507B9384E409E9431Ef3(object):
                 "type": "string"
                 },
                 "timeTaken": {
-                "type": "integer"
+                "type": "number"
                 },
                 "type": {
                 "type": "string"
@@ -539,19 +521,19 @@ class JSONSchemaValidatorF04B76067507B9384E409E9431Ef3(object):
                 "type": "string"
                 },
                 "endTime": {
-                "type": "integer"
+                "type": "number"
                 },
                 "outputStr": {
                 "type": "string"
                 },
                 "startTime": {
-                "type": "integer"
+                "type": "number"
                 },
                 "state": {
                 "type": "string"
                 },
                 "timeTaken": {
-                "type": "integer"
+                "type": "number"
                 }
                 },
                 "type": "object"
@@ -562,7 +544,7 @@ class JSONSchemaValidatorF04B76067507B9384E409E9431Ef3(object):
                 "type": "object"
                 },
                 "timestamp": {
-                "type": "integer"
+                "type": "number"
                 }
                 },
                 "type": "object"
@@ -578,43 +560,38 @@ class JSONSchemaValidatorF04B76067507B9384E409E9431Ef3(object):
                 "type": "boolean"
                 },
                 "addedOn": {
-                "type": "integer"
+                "type": "number"
                 },
                 "configId": {
                 "type": "string"
                 },
                 "currTaskIdx": {
-                "type": "integer"
+                "type": "number"
                 },
                 "description":
                  {
                 "type": "string"
                 },
                 "endTime": {
-                "type": "integer"
+                "type": "number"
                 },
                 "execTime": {
-                "type": "integer"
+                "type": "number"
                 },
                 "imageId": {
                 "type": "string"
                 },
                 "instanceType": {
-                "enum": [
-                "SystemWorkflow",
-                "UserWorkflow",
-                "SystemResetWorkflow"
-                ],
                 "type": "string"
                 },
                 "lastupdateOn": {
-                "type": "integer"
+                "type": "number"
                 },
                 "name": {
                 "type": "string"
                 },
                 "startTime": {
-                "type": "integer"
+                "type": "number"
                 },
                 "state": {
                 "type": "string"
@@ -623,25 +600,25 @@ class JSONSchemaValidatorF04B76067507B9384E409E9431Ef3(object):
                 "items": {
                 "properties": {
                 "currWorkItemIdx": {
-                "type": "integer"
+                "type": "number"
                 },
                 "endTime": {
-                "type": "integer"
+                "type": "number"
                 },
                 "name": {
                 "type": "string"
                 },
                 "startTime": {
-                "type": "integer"
+                "type": "number"
                 },
                 "state": {
                 "type": "string"
                 },
                 "taskSeqNo": {
-                "type": "integer"
+                "type": "number"
                 },
                 "timeTaken": {
-                "type": "integer"
+                "type": "number"
                 },
                 "type": {
                 "type": "string"
@@ -653,19 +630,19 @@ class JSONSchemaValidatorF04B76067507B9384E409E9431Ef3(object):
                 "type": "string"
                 },
                 "endTime": {
-                "type": "integer"
+                "type": "number"
                 },
                 "outputStr": {
                 "type": "string"
                 },
                 "startTime": {
-                "type": "integer"
+                "type": "number"
                 },
                 "state": {
                 "type": "string"
                 },
                 "timeTaken": {
-                "type": "integer"
+                "type": "number"
                 }
                 },
                 "type": "object"
@@ -687,7 +664,7 @@ class JSONSchemaValidatorF04B76067507B9384E409E9431Ef3(object):
                 "type": "string"
                 },
                 "version": {
-                "type": "integer"
+                "type": "number"
                 }
                 },
                 "type": "object"
@@ -701,43 +678,38 @@ class JSONSchemaValidatorF04B76067507B9384E409E9431Ef3(object):
                 "type": "boolean"
                 },
                 "addedOn": {
-                "type": "integer"
+                "type": "number"
                 },
                 "configId": {
                 "type": "string"
                 },
                 "currTaskIdx": {
-                "type": "integer"
+                "type": "number"
                 },
                 "description":
                  {
                 "type": "string"
                 },
                 "endTime": {
-                "type": "integer"
+                "type": "number"
                 },
                 "execTime": {
-                "type": "integer"
+                "type": "number"
                 },
                 "imageId": {
                 "type": "string"
                 },
                 "instanceType": {
-                "enum": [
-                "SystemWorkflow",
-                "UserWorkflow",
-                "SystemResetWorkflow"
-                ],
                 "type": "string"
                 },
                 "lastupdateOn": {
-                "type": "integer"
+                "type": "number"
                 },
                 "name": {
                 "type": "string"
                 },
                 "startTime": {
-                "type": "integer"
+                "type": "number"
                 },
                 "state": {
                 "type": "string"
@@ -746,25 +718,25 @@ class JSONSchemaValidatorF04B76067507B9384E409E9431Ef3(object):
                 "items": {
                 "properties": {
                 "currWorkItemIdx": {
-                "type": "integer"
+                "type": "number"
                 },
                 "endTime": {
-                "type": "integer"
+                "type": "number"
                 },
                 "name": {
                 "type": "string"
                 },
                 "startTime": {
-                "type": "integer"
+                "type": "number"
                 },
                 "state": {
                 "type": "string"
                 },
                 "taskSeqNo": {
-                "type": "integer"
+                "type": "number"
                 },
                 "timeTaken": {
-                "type": "integer"
+                "type": "number"
                 },
                 "type": {
                 "type": "string"
@@ -776,19 +748,19 @@ class JSONSchemaValidatorF04B76067507B9384E409E9431Ef3(object):
                 "type": "string"
                 },
                 "endTime": {
-                "type": "integer"
+                "type": "number"
                 },
                 "outputStr": {
                 "type": "string"
                 },
                 "startTime": {
-                "type": "integer"
+                "type": "number"
                 },
                 "state": {
                 "type": "string"
                 },
                 "timeTaken": {
-                "type": "integer"
+                "type": "number"
                 }
                 },
                 "type": "object"
@@ -810,7 +782,7 @@ class JSONSchemaValidatorF04B76067507B9384E409E9431Ef3(object):
                 "type": "string"
                 },
                 "version": {
-                "type": "integer"
+                "type": "number"
                 }
                 },
                 "type": "object"
@@ -819,7 +791,7 @@ class JSONSchemaValidatorF04B76067507B9384E409E9431Ef3(object):
                 "type": "string"
                 },
                 "version": {
-                "type": "integer"
+                "type": "number"
                 },
                 "workflow": {
                 "properties": {
@@ -830,43 +802,38 @@ class JSONSchemaValidatorF04B76067507B9384E409E9431Ef3(object):
                 "type": "boolean"
                 },
                 "addedOn": {
-                "type": "integer"
+                "type": "number"
                 },
                 "configId": {
                 "type": "string"
                 },
                 "currTaskIdx": {
-                "type": "integer"
+                "type": "number"
                 },
                 "description":
                  {
                 "type": "string"
                 },
                 "endTime": {
-                "type": "integer"
+                "type": "number"
                 },
                 "execTime": {
-                "type": "integer"
+                "type": "number"
                 },
                 "imageId": {
                 "type": "string"
                 },
                 "instanceType": {
-                "enum": [
-                "SystemWorkflow",
-                "UserWorkflow",
-                "SystemResetWorkflow"
-                ],
                 "type": "string"
                 },
                 "lastupdateOn": {
-                "type": "integer"
+                "type": "number"
                 },
                 "name": {
                 "type": "string"
                 },
                 "startTime": {
-                "type": "integer"
+                "type": "number"
                 },
                 "state": {
                 "type": "string"
@@ -875,25 +842,25 @@ class JSONSchemaValidatorF04B76067507B9384E409E9431Ef3(object):
                 "items": {
                 "properties": {
                 "currWorkItemIdx": {
-                "type": "integer"
+                "type": "number"
                 },
                 "endTime": {
-                "type": "integer"
+                "type": "number"
                 },
                 "name": {
                 "type": "string"
                 },
                 "startTime": {
-                "type": "integer"
+                "type": "number"
                 },
                 "state": {
                 "type": "string"
                 },
                 "taskSeqNo": {
-                "type": "integer"
+                "type": "number"
                 },
                 "timeTaken": {
-                "type": "integer"
+                "type": "number"
                 },
                 "type": {
                 "type": "string"
@@ -905,19 +872,19 @@ class JSONSchemaValidatorF04B76067507B9384E409E9431Ef3(object):
                 "type": "string"
                 },
                 "endTime": {
-                "type": "integer"
+                "type": "number"
                 },
                 "outputStr": {
                 "type": "string"
                 },
                 "startTime": {
-                "type": "integer"
+                "type": "number"
                 },
                 "state": {
                 "type": "string"
                 },
                 "timeTaken": {
-                "type": "integer"
+                "type": "number"
                 }
                 },
                 "type": "object"
@@ -939,7 +906,7 @@ class JSONSchemaValidatorF04B76067507B9384E409E9431Ef3(object):
                 "type": "string"
                 },
                 "version": {
-                "type": "integer"
+                "type": "number"
                 }
                 },
                 "type": "object"
