@@ -22,13 +22,7 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 
-
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-    unicode_literals,
-)
+from __future__ import absolute_import, division, print_function, unicode_literals
 
 
 RESPONSE_CODES = {
@@ -70,6 +64,7 @@ RATE_LIMIT_RESPONSE_CODE = 429
 
 EXPECTED_RESPONSE_CODE = {
     'GET': [200, 202, 204, 206],
+    'PATCH': [200, 201, 202, 204, 206],
     'POST': [200, 201, 202, 204, 206],
     'PUT': [200, 201, 202, 204, 206],
     'DELETE': [200, 202, 204, 206],
